xquery version "1.0";

declare option exist:serialize "expand-xincludes=no";

declare namespace session="http://exist-db.org/xquery/session";
declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

import module namespace ristenutil="http://www.risten.no/shared/util"
                     at "../xquery/ristenutil.xqm";

(: Assemble the query string :)
declare function local:build-query($id as xs:string) as xs:string
{
    let $coll := ristenutil:get-collection()
    return
        concat("for $r in collection('",
                $coll,
                "')//(macro|micro|nano)[@id eq '",
                $id,
                "'] return $r")
};

(: Present an overview of query results :)
declare function local:displayHitlist($hit as node() ) as element()
{
    let $collID:= session:get-attribute("collection"),
        $classlangs := ristenutil:get-class-langs( $collID )
    return
        <query-results>
            {
                $classlangs,
                $hit
            }
        </query-results>
};

(: Main function - retrieves some request and session attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
    let $classID := request:get-parameter("classID", "")
    return
              let $query := local:build-query($classID),
                  $hit   := util:eval( $query )
              return
                if (empty($hit)) then (
                    <p class="searchterm"><i18n:text>NoHit</i18n:text>
                    «{$classID}» !</p>,
                    <p>{$query}</p>
                    )
                else (
					local:displayHitlist($hit)
					)
};

<document>
    <header>
      <style href="risten_edit_classes_SD-class_search-entries.css"/>
      <title>Add Class Label</title>
    </header>
	<body>
        <section title="AddClassLabel" catalogue="classedit">
            { let $start := util:system-time() return
				(
					local:main(),
                     <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                            { round-half-to-even( seconds-from-duration(
                              util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
