xquery version "1.0";

declare namespace session="http://exist-db.org/xquery/session";
declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

import module namespace ristenutil="http://www.risten.no/shared/util"
                     at "../xquery/ristenutil.xqm";

(: Assemble the query string :)
declare function local:build-query($id as xs:string,
							     $lang as xs:string)
							    as xs:string
{
    let $coll := ristenutil:get-collection()
    return
        concat("for $r in collection('",
                $coll,
                "')//*[@id eq '",
                $id,
                "']/label[@xml:lang eq '",
                $lang,
                "'] return $r")
};

(: Present an overview of query results :)
declare function local:displayHitlist($hits as node()+, $classID as xs:string)
as element()
{
<query-results id="{$classID}">
    {
        $hits
    }
</query-results>
};

(: Main function - retrieves some request and session attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
    let $class := request:get-parameter("classID", ""),
        $lang  := request:get-parameter("lang", "")
    return
              let $query := local:build-query($class, $lang),
                  $hits  := util:eval( $query )
              return
                if (empty($hits)) then (
                    <p class="searchterm"><i18n:text>NoHit</i18n:text>
                    «{$class}» / «{$lang}»!</p>,
                    <p>{$query}</p> )
                else (
(: DEBUG only - output some extra info :)
(:					<p>Your session attributes: {$session}<br/>
					Your request attributes: {$request}<br/>
					Your old/short search query: {$queryOld}<br/>
					Your complete search query:<br/>
					{$query}
					</p>,
					<p class="searchterm">
					<i18n:text>UrSrchTrm</i18n:text>:
					«{$class}», «{$lang}»</p>,
                    <p>{$query}</p>
					, :)
					local:displayHitlist($hits, $class)
					)
};

<document>
    <header>
      <style href="risten_edit_classes_SD-class.css"/>
      <title>Confirm Delete!</title>
    </header>
	<body>
        <section title="ConfirmDeleteTitle" catalogue="classedit">
            { let $start := util:system-time() return
				(
					local:main(),
                     <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                            { round-half-to-even( seconds-from-duration(
                              util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
