xquery version "1.0";

declare namespace session="http://exist-db.org/xquery/session";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";
declare namespace source="http://apache.org/cocoon/source/1.0";

import module namespace ristenutil="http://www.risten.no/shared/util" at "../xquery/ristenutil.xqm";

(: Update the classification document: :)
declare function local:store-translations($docref as xs:string, $lang as xs:string)
							    as node()+
{
    let $coll  := ristenutil:get-collection()
    let $xlang := if ($lang eq 'nb') then
                     'nob'
                   else if ($lang eq 'no') then
                     'nor'
                   else if ($lang eq 'se') then
                     'sme'
                   else if ($lang eq 'nn') then
                     'nno'
                   else if ($lang eq 'sv') then
                     'swe'
                   else if ($lang eq 'fi') then
                     'fin'
                   else if ($lang eq 'en') then
                     'eng'
                   else $lang
    return
      <ol>{
        for $tr in doc($docref)//message
        let $id := $tr/@key cast as xs:string
        return
            if (collection($coll)//
                (macro|micro|nano)[@id eq $id]/label[@xml:lang = $xlang]) then
            <li><i18n:text catalogue="classedit">NothingAdded</i18n:text></li>
            else
            (
              update insert
                       <label xml:lang="{$xlang}">{$tr/text()}</label>
                     following collection($coll)//(macro|micro|nano)[@id eq $id]/label[last()],
              <li>Key: {$id} - {$tr/text()}</li>
            )
      }</ol>
};

(: Update the classification document: :)
declare function local:update-meta($lang as xs:string) as node()
{
    let $coll  := ristenutil:get-collection()
    let $xlang := if ($lang eq 'nb') then
                     'nob'
                   else if ($lang eq 'no') then
                     'nor'
                   else if ($lang eq 'se') then
                     'sme'
                   else if ($lang eq 'nn') then
                     'nno'
                   else if ($lang eq 'sv') then
                     'swe'
                   else if ($lang eq 'fi') then
                     'fin'
                   else if ($lang eq 'en') then
                     'eng'
                   else $lang
    return
        if ( collection($coll)/classmeta/langs/lang = $xlang ) then
          <i18n:text catalogue="classedit">AlreadyThere</i18n:text>
        else
        (
          update insert
                   <lang>{$xlang}</lang>
                 into collection($coll)/classmeta/langs,
          <i18n:text>{$xlang}</i18n:text>
        )
};


(: Main function - retrieves some request and session attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
(:
for $lang in
/classmeta[id eq 'SD-class']/langs/lang
return <test>{$lang/node()}</test>
:)
let $eXistROOT  := util:system-property("user.dir"),
    $importlang := request:get-parameter("importlang", ""),
    $coll       := session:get-attribute("collection"),
    $docref     := concat('file://',
                           $eXistROOT,
                          '/webapp/risten/translations/',
                           $coll,
                          '_',
                           $importlang,
                          '.xml'),
    $result     := local:store-translations($docref, $importlang),
    $metaupdate := local:update-meta($importlang)

return <p>
            <i18n:translate>
              <i18n:text i18n:catalogue="classedit">ImportMessage</i18n:text>
              <i18n:param>{$docref}</i18n:param>
              <i18n:param>{$metaupdate}</i18n:param>
            </i18n:translate>
        <br/>
        {$result}</p>

};

<document>
    <header>
      <style href="risten_edit_classes_SD-class.css"/>
      <title>I18N file imported!</title>
    </header>
	<body>
        <section title="FileImported" catalogue="classedit">
            { let $start := util:system-time() return
				(
					local:main(),
                     <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                            { round-half-to-even( seconds-from-duration(
                              util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
