<?xml version="1.0"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exist="http://exist.sourceforge.net/NS/exist"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">

  <xsl:import href="../../../xslt/searchdocu2html.xsl" />

  <xsl:param name="queryfile"/>

    <xsl:template match="query-results">
      <xsl:apply-templates select="classification">
        <xsl:with-param name="showlang" select="./@showlang"/>
        <xsl:with-param name="showclass" select="./@showclass"/>
        <xsl:with-param name="termcoll" select="./@termcoll"/>
      </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="classification">
      <xsl:param name="showlang"/>
      <xsl:param name="showclass"/>
      <xsl:param name="termcoll"/>
      <form action="save-catalogue.xq" target="editor">
        <input type="submit" value="classedit:UpdateCatalogs" i18n:attr="value"/>
      </form>

      <form action="import-translations.xq" target="editor">
        <select name="importlang" size="1">
          <option value="se"><i18n:text>se</i18n:text></option>
          <option value="smj"><i18n:text>smj</i18n:text></option>
          <option value="sma"><i18n:text>sma</i18n:text></option>
          <option value="smn"><i18n:text>smn</i18n:text></option>
          <option value="sms"><i18n:text>sms</i18n:text></option>
          <option value="no"><i18n:text>no</i18n:text></option>
          <option value="sv"><i18n:text>sv</i18n:text></option>
          <option value="fi"><i18n:text>fi</i18n:text></option>
          <option value="en"><i18n:text>en</i18n:text></option>
        </select>
        <input type="submit" value="classedit:ImportTranslations" i18n:attr="value"/>
      </form>

      <ul class="hitlist" id="classedit" showlang="{$showlang}"
          termcoll="{$termcoll}" showclass="{$showclass}">
      <li>
      <a target="editor">
      <xsl:attribute name="href">
        <xsl:value-of select="concat('search-class-entries.xq?collection=',
                                      $termcoll,'&amp;colltype=terms&amp;class=')"/>
      </xsl:attribute>
      <i18n:text catalogue="classedit">NoClass</i18n:text>
      </a>
      </li>
      <xsl:apply-templates >
        <xsl:with-param name="showlang" select="$showlang"/>
        <xsl:with-param name="termcoll" select="$termcoll"/>
      </xsl:apply-templates>
      </ul>
    </xsl:template>

    <xsl:template match="macro|micro|nano">
      <xsl:param name="showlang"/>
      <xsl:param name="termcoll"/>
      <li>
      <a target="editor">
      <xsl:attribute name="href">
        <xsl:value-of select="concat('search-class-entries.xq?collection=',
                                      $termcoll,
                                      '&amp;colltype=terms&amp;class=',
                                      @id)"/>
      </xsl:attribute>
      <xsl:value-of select="@id"/>
      </a>
      <!-- Initial code to support addition and removing of whole classes follows;
           it does not yet work: -->
      <!--xsl:text> </xsl:text>
      <a class="add" target="editor">
      <xsl:attribute name="href">
        <xsl:value-of select="concat('add-class.xq?superclass=',
                                      ../@id,
                                      '&amp;precedingclass',
                                      preceding-sibling::*[1]/@id)"/>
      </xsl:attribute>
       + </a>
      <a class="remove" target="editor">
      <xsl:attribute name="href">
        <xsl:value-of select="concat('ask-delete-class.xq?id=',@id)"/>
      </xsl:attribute>
       - </a-->
      <ul>
        <xsl:choose>
          <!-- Check whether all languages should be listed (the default): -->
          <xsl:when test="$showlang = 'all'">
            <xsl:apply-templates select="label">
              <xsl:with-param name="showlang" select="$showlang"/>
              <xsl:with-param name="classID" select="@id"/>
            </xsl:apply-templates>
            <xsl:if test="ancestor::query-results/langs/lang[
                          not(. = current()/label/@xml:lang)]">
              <li>
                <a class="add" target="editor">
                  <xsl:attribute name="href">
                    <xsl:value-of select="concat('add-label.xq?classID=',
                                                 @id)"/>
                  </xsl:attribute> + </a>
              </li>
            </xsl:if>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="label[@xml:lang = $showlang]">
              <xsl:with-param name="showlang" select="$showlang"/>
              <xsl:with-param name="classID" select="@id"/>
            </xsl:apply-templates>
          </xsl:otherwise>
        </xsl:choose>

      <xsl:choose>
        <xsl:when test="name() ='macro' ">
          <xsl:apply-templates select="micro">
            <xsl:with-param name="showlang" select="$showlang"/>
            <xsl:with-param name="termcoll" select="$termcoll"/>
          </xsl:apply-templates>
        </xsl:when>
        <xsl:when test="name() ='micro' ">
          <xsl:apply-templates select="nano">
            <xsl:with-param name="showlang" select="$showlang"/>
            <xsl:with-param name="termcoll" select="$termcoll"/>
          </xsl:apply-templates>
        </xsl:when>
      </xsl:choose>
      </ul>
      </li>
    </xsl:template>

    <xsl:template match="label">
      <xsl:param name="showlang"/>
      <xsl:param name="classID"/>
      <li>
        <a class="remove" target="editor">
        <xsl:attribute name="href">
          <xsl:value-of select="concat('confirm-delete-label.xq?lang=',
                                       @xml:lang,
                                       '&amp;classID=',
                                       $classID)"/>
        </xsl:attribute> - </a>
        <xsl:text> </xsl:text>
        <span class="lang"><xsl:value-of select="@xml:lang"/></span>
        <xsl:text> – </xsl:text>
        <a target="editor">
          <xsl:attribute name="href">
            <xsl:value-of select="concat('edit-entry.xq?id=',
                                          $classID,
                                          '&amp;lang=',
                                          @xml:lang)"/>
          </xsl:attribute>
          <xsl:apply-templates />
        </a>
      </li>
    </xsl:template>

</xsl:stylesheet>
