xquery version "1.0";

declare namespace session="http://exist-db.org/xquery/session";
declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

declare function local:get-doc($lang as xs:string) as xs:string
{
    let $doc := concat('/db/ordbase/terms/SD-terms/terms-',$lang,'.xml')
    return $doc
};

(: Save an edited entry, the grammar part common to all senses: :)
declare function local:saveentry() as element()
{
	let $id    := request:get-parameter("id",    ""),
		$lang  := request:get-parameter("lang",  ""),
		$entry := request:get-parameter("entry", ""),
		$pos   := request:get-parameter("pos",   ""),
		$orth  := request:get-parameter("orthstatus", ""),
		$checked   := request:get-parameter("commonchecked", ""),
		$inflmajor := request:get-parameter("inflmajor", ""),
		$inflminor := request:get-parameter("inflminor", ""),
		$inflexmpl := request:get-parameter("inflexmpl", "")

    let $user := session:get-attribute("user") ,
        $pass := session:get-attribute("password"),
		$coll  := "/db/ordbase/terms/SD-terms",
		$doc   := local:get-doc($lang),
		$db    := concat('xmldb:exist://',$coll)

	let $checkeddate := if ($checked eq "true") then
	                     current-date()
	                   else ()

	let $paramters := request:get-parameter-names()

    (: $collection should refer to the collection, not the
       document in the collecion! :)
    let $collection := xmldb:collection( $db, $user, $pass)

    (: The document reference needs to include the collection
       path even though it is given in the $collection argument in
       the xmldb:update command (below). :)
    let $xupdate :=
    <xupdate:modifications version="1.0"
      xmlns:xupdate="http://www.xmldb.org/xupdate" >
      <xupdate:update select="doc('{$doc}')/terminology/entry[@id = '{$id}']/common" >
        <head pos="{$pos}">{$entry}</head>
        <infl major="{$inflmajor}" minor="{$inflminor}" >{$inflexmpl}</infl>
        <orth status="{$orth}"/>
        <qa checked="{$checked}" when="{$checkeddate}" who="{$user}" />
      </xupdate:update>
    </xupdate:modifications>

    let $dummy := xmldb:update($collection, $xupdate)

    return
           <p>Parameter: {$paramters}<br/>
              Database: {$db}<br/>
              ID: {$id}<br/>
              Oppslag: {$entry}<br/>
              XUpdate: {$xupdate}<br/>
              Result: {$dummy}<br/>
              Lagra!</p>
};

(: Create filter expression from query term, field and mode :)
declare function local:filter-expr($record as xs:string) as xs:string
{
    let $pos := request:get-parameter("pos", "S")
    let $t   := concat("'", $record, "\", $pos, "'")
    return
        concat("@id &amp;= ", $t)
};

(: Assemble the query string :)
declare function local:build-query($record as xs:string, $entrylang as xs:string)
as xs:string
{
    let $expr := local:filter-expr($record),
		$doc  := local:get-doc($entrylang)
    return
        concat("for $r in document('", $doc, "')//entry[",
            $expr, "] return $r")
};

(: Modify the query results before display:  :)
declare function local:display($entrylang as xs:string, $hits as node()+)
as element()
{
	let $entry   := item-at($hits, 1),
		$common  := $entry/common,
		$senses  := $entry/senses,
		$id      := $entry/@id
	return
		<entry xml:lang="{$entrylang}" id="{$id}">
		{$common}
		<senses>
		{
		for $s in $entry/senses/sense
		let $status := $s/@status
		order by $status
		return <sense href="{$s/@idref}" status="{$status}" mainref="{$s/@mainref}">
		       	<topic>
					<top  id="{$s/topicClass/@top}"  />
					<mid  id="{$s/topicClass/@mid}"  />
					<botm id="{$s/topicClass/@botm}" />
		       	</topic>
		       	{
		       	if ( $s/def ) then
		       	    $s/def
		       	else (),
		       	if ( $s/synonyms ) then
		       	    $s/synonyms
		       	else ()
		       	}
		       </sense>
		}
		</senses>
		</entry>
};

(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
	let $record    := request:get-parameter("id", ""),
		$entry     := request:get-parameter("entry", ""),
		$entrylang := request:get-parameter("lang", ""),
		$inputtype := request:get-parameter("common", ""),
		$entry     := request:get-parameter("entry", "")

    let $t := if ($entrylang = "sme") then
                  session:set-attribute("record-exists", "yes")
              else session:set-attribute("record-exists", "")

    return
        if(string-length($record) = 0) then
                <p>WARNING: There was an error with this request!
                   Please check with the webmaster. <small>Cause:
                   No request record value.</small>
                </p>
        else
            let $query := local:build-query($entry, $entrylang),
                $saveresult :=
                    if ($inputtype = 'savecommon') then
                      local:saveentry()
                    else <p>Nothing saved!</p>,
                $hits := util:eval( $query )
            return
                if (empty($hits)) then (
                    <p>ERROR! Record {$record} not found!</p>,
                    <p>Your language: {$entrylang}</p>,
                    <p>Your request: {$record}</p>,
                    <p>Your entry: {$entry}</p>,
                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p> )
                else (
(: DEBUG:           <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p>,
                    <p>The input type: {$inputtype}</p>
                    ,
                    <p>The save result: {$saveresult}</p>
                    , :)
                    local:display($entrylang, $hits)
                    )
};

<document>
	<body>
        <section title="DictTitle">
            { let $start := util:system-time() return
				(
					local:main(),
            		  <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                          { round-half-to-even( seconds-from-duration(
                            util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
