xquery version "1.0";

declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

(: Assemble the query string :)
declare function local:build-query($record as xs:string, $entrylang as xs:string)
as xs:string
{
    let $doc  := concat('/db/ordbase/terms/SD-terms/terms-',$entrylang,'.xml')
    return
        concat("for $r in document('", $doc, "')",
            $record," return $r")
};

(: Modify the query results before display - in this case just add the
   language of the entry:  :)
declare function local:display($entrylang as xs:string, $hits as node()+)
as element()
{
	let $entry   := item-at($hits, 1),
		$common  := $entry/common,
		$senses  := $entry/senses,
		$changes := $entry/changes,
		$id      := $entry/@id

	return
		<entry xml:lang="{$entrylang}" id="{$id}">
          {$common}
          {$senses}
          {$changes}
		</entry>
};

(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
	let $entrylang := request:get-parameter("entrylang", ""),
		$request   := request:get-parameter("request", "")
    return
        if(string-length($request) = 0) then
                <p>WARNING: There was an error with this request!
                   Please check with the webmaster. <small>Cause:
                   No request record value.</small>
                </p>
        else
            let $query := local:build-query($request, $entrylang),
                $hits := util:eval( $query )
            return
                if (empty($hits)) then (
                    <p>ERROR! Record {$request} not found!</p>,
                    <p>Your language: {$entrylang}</p>,
                    <p>Your request: {$request}</p>,
                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p> )
                else (
                    local:display($entrylang, $hits)
                    )
};

<document>
	<body>
        <section title="DictTitle">
            { let $start := util:system-time() return
				(
					local:main(),
            		  <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                          { round-half-to-even( seconds-from-duration(
                            util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
