xquery version "1.0";

declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

(: Assemble the query string :)
declare function local:build-query($record as xs:string, $entrylang as xs:string)
as xs:string
{
    let $doc  := concat('/db/ordbase/terms/SD-terms/terms-',$entrylang,'.xml')
    return
        concat("for $r in document('", $doc, "')",
            $record," return $r")
};

(: Modify the query results before display:  :)
declare function local:display($entrylang as xs:string, $hits as node()+)
as element()
{
	let $entry   := item-at($hits, 1),
		$common  := $entry/common,
		$senses  := $entry/senses,
		$id      := $entry/@id,
		$date    := current-dateTime()
	return
		<entry xml:lang="{$entrylang}" id="{$id}" date="{$date}">
		{$common}
		<senses>
		{
		for $s in $entry/senses/sense
		let $status := $s/@status
		order by $status
		return <sense href="{$s/@idref}" status="{$status}" mainref="{$s/@mainref}">
		       	<topic>
					<top  id="{$s/topicClass/@top}"  />
					<mid  id="{$s/topicClass/@mid}"  />
					<botm id="{$s/topicClass/@botm}" />
		       	</topic>
		       	{
		       	if ( $s/def ) then
		       	    $s/def
		       	else (),
		       	if ( $s/synonyms ) then
		       	    $s/synonyms
		       	else ()
		       	}
		       </sense>
		}
		</senses>
		</entry>
};

(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
	let $entrylang := request:get-parameter("entrylang", ""),
		$request   := request:get-parameter("request", "")
    return
        if(string-length($request) = 0) then
                  <p>This functionality is not yet in place.</p>
        else
            let $query := local:build-query($request, $entrylang),
                $hits := util:eval( $query )
            return
                if (empty($hits)) then
                  <p>This functionality is not yet in place.</p>
                else
                  <p>This functionality is not yet in place.</p>
};

<document>
	<body>
        <section title="DictTitle">
            { let $start := util:system-time() return
				(
					local:main(),
            		  <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                          { round-half-to-even( seconds-from-duration(
                            util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
