xquery version "1.0";

(: declare option exist:profiling "enabled=yes verbosity=10 logger=xquery.profiling"; :)

declare namespace session="http://exist-db.org/xquery/session";
declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";
declare namespace xmldb="http://exist-db.org/xquery/xmldb";

import module namespace save="http://www.risten.no/edit/save" at "xquery/saveroutines.xqm";
import module namespace ristenutil="http://www.risten.no/shared/util"  at "../xquery/ristenutil.xqm";

(: Assemble the query string :)
declare function local:build-query($record as xs:string, $entrylang as xs:string)
as xs:string
{
    let $pos      := request:get-parameter("pos", "S"),
        $newRecID := ristenutil:makeTermID($record, $pos),
        $expr     := ristenutil:id-filter($newRecID),
		$doc      := ristenutil:get-doc($entrylang)
    return
        concat("for $r in document('", $doc, "')//entry[",
            $expr, "] return $r")
};


(: Check for the existence of the new entry: :)
declare function local:check-exists($entry as xs:string, $entrylang as xs:string)
                   as xs:boolean
{
    let $query := local:build-query($entry, $entrylang),
        $hits  := util:eval( $query ),
        $count := count($hits)
    return if ( $count = 0 ) then
             false()
           else
             true()
};

(: Check for the existence of the language in the term center -
   only one term/language in each term record: :)
declare function local:check-center($centerid as xs:string, $entrylang as xs:string)
                   as xs:boolean
{
    let $query := concat("for $r in document",
                         "('/db/ordbase/terms/SD-terms/termcenter.xml')",
                         "/termCenter/entry[@id='", $centerid,
                         "']/entryref[@xml:lang='", $entrylang,
                         "'] return $r"),
        $hits  := util:eval( $query ),
        $count := count($hits)
    return if ( $count = 0 ) then
             false()
           else
             true()
};


(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
	let $centerid  := request:get-parameter("id",     ""),
		$entrylang := request:get-parameter("lang",   ""),
		$rawentry  := request:get-parameter("entry",  ""),
		$pos       := request:get-parameter("pos",    ""),
		$entry     := ristenutil:cleanEntry(     $rawentry  )

    let $l := session:set-attribute("entrylang", $entrylang),
        $p := session:set-attribute("pos",       $pos)

    let $exists     := local:check-exists($entry,    $entrylang),
        $cntrexists := local:check-center($centerid, $entrylang)
    
    let $dummy := util:log("info", "main")

    return
      if ( $cntrexists ) then
        <p>WARNING: The term record «{$centerid}» does already have
           an entry for this language! If you want to add alternative
           terms, please add them as synonyms (click the existing
           term to add synonyms).</p>
      else
        if( $exists ) then
            let $savedentry  := save:saveExistingEntry($centerid),
                $savedcenter := save:updatecenter($centerid),
                $query       := local:build-query($entry, $entrylang),
                $hits        := util:eval( $query )
            return (
(:                    <p>The result: {$savedentry}</p>,
                    <p>In Term Record: {$savedcenter}</p>, :)
                    ristenutil:display($entrylang, $hits)
                    )
        else
            let $saveresult  := save:saveNewEntry($centerid),
                $savedcenter := save:updatecenter($centerid),
                $query       := local:build-query($entry, $entrylang),
                $hits        := util:eval( $query )
            return
                if (empty($hits)) then (
                    <p>ERROR! Record {$centerid} not found!</p>,
                    <p>Your language: {$entrylang}</p>,
                    <p>Your request: {$centerid}</p>,
                    <p>Your entry: {$entry}</p>,
                    <p>New entry exists: {$exists}</p>,
                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p> )
                else (
(: DEBUG:           <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p>,
                    <p>The save result: {$saveresult}</p>
                    ,
                    <p>The article does exist: {$exists}</p>
                    , :)
                    ristenutil:display($entrylang, $hits)
                    )
};

<document>
	<body>
        <section title="DictTitle">
            { let $start := util:system-time(),
            		 $entrylang := request:get-parameter("lang",   "")
            	  return
				(
					ristenutil:pre-main($entrylang, local:main()),
                     <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                          { round-half-to-even( seconds-from-duration(
                            util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
