xquery version "1.0";

declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace dc="http://purl.org/dc/elements/1.1/";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

(: Create filter expression from query term, field and mode :)
declare function local:filter-expr($record as xs:string) as xs:string
{
    let $t := concat("'", $record, "'")
    return
        concat("@id &amp;= ", $t)
};

(: Assemble the query string :)
declare function local:build-query($record as xs:string) as xs:string
{
    let $expr := local:filter-expr($record),
		$docs := "'/db/ordbase/terms/SD-terms/termcenter.xml'"
    return
        concat("for $r in document(", $docs, ")//entry[",
            $expr, "] return $r")
};


(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
    let $record := request:get-parameter("record", "")
    return
        if(string-length($record) = 0) then
                <p>WARNING: There was an error with this request!
                   Please check with the webmaster. <small>Cause:
                   No request record value.</small>
                </p>
        else
            let $query := local:build-query($record),
                $hits := util:eval( $query )
            return
                if (empty($hits)) then
                    <p>ERROR! Record {$record} not found!</p>
                else (
(:                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p>
                    , :)
                    $hits
                    )
};

<document>
	<body>
        <section title="TermTitle">
            { let $start := util:system-time() return
				(
					local:main(),
           			<p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                            { seconds-from-duration(util:system-time()-$start) }
                          </i18n:param>
             	       </i18n:translate>
					</p>
				)
			}
        </section>
    </body>
</document>
