xquery version "1.0";

declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace dc="http://purl.org/dc/elements/1.1/";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

(: Create filter expression from query term, field and mode :)
declare function local:filter-expr($record as xs:string) as xs:string
{
    let $t := concat("'", $record, "'")
    return
        concat("@id &amp;= ", $t)
};

(: Assemble the query string :)
declare function local:build-query($record as xs:string) as xs:string
{
    let $expr := local:filter-expr($record),
		$docs := "'/db/ordbase/terms/SD-terms/termcenter.xml'"
    return
        concat("for $r in document(", $docs, ")//entry[",
            $expr, "] return $r")
};

(: Modify/enhance the query results before display:
   Main purpose: to add classification labels, and
   to remove unwanted senses before display. Does not
   work due to limitations in eXist (XIncludes are
   not expanded until serialisation time - thus not
   available for inspection at this point.
   Solution:
   Only classification labels added, the sense filtering
   is deferred to XSLT processing, when the XIncludes
   are available :)
declare function local:display($hits as node()+)
as element()
{
	let $current := item-at($hits, 1),
		$top := $current/topicClass/@top,
		$mid := $current/topicClass/@mid,
		$botm := $current/topicClass/@botm,
		$count := count($current/entryref)
	return
		<entry>
		{
		for $p in 1 to $count
		let $entry	:= item-at($current/entryref, $p),
			$lang	:= $entry/@xml:lang,
			$common	:= $entry
		return
			<entryref xml:lang="{$lang}">
			{$common (: ,
			for $sense in $entry/senses/sense
			let $sensetop  := $sense/topicClass/@top,
				$sensemid  := $sense/topicClass/@mid,
				$sensebotm := $sense/topicClass/@botm
			return
				if ( ($top = $sensetop) and
					 ($mid = $sensemid) and
					 ($botm = $sensebotm) ) then
					 $sense
				else ()
:)			}
			</entryref>
		}
		</entry>
};

(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
    let $record := request:get-parameter("record", "")
    return
        if(string-length($record) = 0) then
                <p>WARNING: There was an error with this request!
                   Please check with the webmaster. <small>Cause:
                   No request record value.</small>
                </p>
        else
            let $query := local:build-query($record),
                $hits := util:eval( $query )
            return
                if (empty($hits)) then
                    <p>ERROR! Record {$record} not found!</p>
                else (
(:                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p>
                    , :)
                    $hits
(:                    local:display($hits) :)
                    )
};

<document>
	<body>
        <section title="TermTitle">
            { let $start := util:system-time() return
				(
					local:main(),
                     <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param>
                          { round-half-to-even( seconds-from-duration(
                            util:system-time() - $start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
