<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">

    <!-- Adds the basic HTML wrapping based on the doc. structure provided by the XQuery -->
    <xsl:import href="../../../../xslt/searchdocu2html.xsl"/>
    
	<xsl:template match="entry">
		<div class="entry">
			<h3><i18n:text>Entry#</i18n:text>:
			<xsl:value-of select="@id" /></h3>
			<xsl:apply-templates select="topicClass"/>
			<xsl:call-template name="common" />
		</div>
	</xsl:template>

	<xsl:template name="common">
		<div class="common">

		<!-- Note that to get method="POST" to work correctly with UTF-8,
		     all three of method, accept-charset, and enctype should be specified -->
		<form action="save-new-lang-entry.xq"
		      method="POST"
		      accept-charset="UTF-8"
		      enctype="multipart/form-data" >

          <input type="hidden" name="id"   value="{@id}" />
          <input type="hidden" name="top"  value="{topicClass/@top}" />
          <input type="hidden" name="mid"  value="{topicClass/@mid}" />
          <input type="hidden" name="botm" value="{topicClass/@botm}" />

         <!-- Encapsulate the form fields in a table for prettier layout: -->
         <table>

         <tr>
         <!-- Building the language menu such that the previous language selection
              is used by default. -->
		 <td>
		 <span class="entryword"><i18n:text>Language</i18n:text>:
		 </span>
		 </td>
		 <td>
           <xsl:apply-templates select="termlangs">
             <xsl:with-param name="lang" select="@xml:lang" />
             <xsl:with-param name="existlangs" select="defined-langs/@langs" />
           </xsl:apply-templates >
         </td></tr>

         <tr>
		 <td><span class="entryword"><i18n:text>EntryWord</i18n:text>:
		 </span>
		 </td>
		 <td>
		  <input type="text" size="20" name="entry" tabindex="1">
		    <xsl:attribute name="value"/>
		  </input>
        </td></tr>

        <tr>
		<!-- The POS field/menu -->
        <td><span class="pos"><i18n:text>POS</i18n:text>:
		</span>
        </td>
		 <td>
        <select size="1" name="pos">
            <option value="S">
              <xsl:if test="@pos = ('' or 'S')">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">S</i18n:text>
            </option>
            <option value="A">
              <xsl:if test="@pos = 'A'">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">A</i18n:text>
            </option>
            <option value="V">
              <xsl:if test="@pos = 'V'">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">V</i18n:text>
            </option>
            <option value="Adv">
              <xsl:if test="@pos = 'Adv'">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">Adv</i18n:text>
            </option>
            <option value="PP">
              <xsl:if test="@pos = 'PP'">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">PP</i18n:text>
            </option>
            <option value="Pron">
              <xsl:if test="@pos = 'Pron'">
                <xsl:attribute name="selected">1</xsl:attribute>
              </xsl:if>
              <i18n:text catalogue="pos">Pron</i18n:text>
            </option>
         </select>
        </td></tr>

        <tr>
        <td>
		<button title="ResetButtonTitle" type="reset" i18n:attr="title" >
		  <i18n:text>Reset</i18n:text>
        </button>
		 </td>
		 <td>
		<button title="SaveButtonTitle" type="submit" i18n:attr="title"
		        value="savecommon" name="common" >
          <i18n:text>Save</i18n:text>
        </button>
        </td>
        </tr>

         </table>

		</form>
		</div>
	</xsl:template>

<!-- Comment until I've decided what to do with these elements:
	<xsl:template match="orth">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="qa">
		<xsl:apply-templates/>
	</xsl:template>
-->

    <xsl:template match="topicClass">
		<span class="topic">
			<span class="top">
	    		<i18n:text i18n:catalogue="SD-class">
	    			<xsl:value-of select="@top"/>
	    		</i18n:text>
	    	</span>
	    	<xsl:if test="./@mid != ''">
	    		<span class="mid"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    				<xsl:value-of select="@mid"/>
	    			</i18n:text>
	    		</span>
	    		<xsl:if test="./@botm != ''">
	    			<span class="botm"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    					<xsl:value-of select="@botm"/>
	    				</i18n:text>
	    			</span>
	    		</xsl:if>
	    	</xsl:if>
		</span>
    </xsl:template>

    <xsl:template match="changes">
      <div><i18n:text>ChangeLog</i18n:text>:</div>
      <table class="changelog" >
        <tr>
          <th><i18n:text>ChangeWho</i18n:text>:</th>
          <th><i18n:text>ChangeWhen</i18n:text>:</th>
          <th><i18n:text>ChangeWhat</i18n:text>:</th>
        </tr>
        <xsl:apply-templates >
          <xsl:sort select="@when" />
        </xsl:apply-templates >
      </table>
    </xsl:template>

    <xsl:template match="change">
      <tr>
        <td><xsl:value-of select="@who"  /></td>
        <td><xsl:value-of select="@when" /></td>
        <td><xsl:value-of select="@what" /></td>
      </tr>
    </xsl:template>

  <xsl:template match="termlangs">
	<xsl:param name="lang"/>
	<xsl:param name="existlangs"/>
    <select size="1" name="lang">
      <xsl:apply-templates select="language[not(contains($existlangs,@id))]">
        <xsl:with-param name="lang" select="$lang" />
      </xsl:apply-templates >
    </select>
  </xsl:template>

  <xsl:template match="language">
	<xsl:param name="lang"/>
    <option title="{@id}" >
      <xsl:attribute name="value">
        <xsl:value-of select="@id" />
      </xsl:attribute>
      <xsl:if test="@id = $lang">
        <xsl:attribute name="selected" />
      </xsl:if>
      <i18n:text><xsl:value-of select="@id"/></i18n:text>
    </option>
  </xsl:template>

</xsl:stylesheet>
