<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exist="http://exist.sourceforge.net/NS/exist"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:xi="http://www.w3.org/2001/XInclude"
    version="1.0">
    
    <xsl:import href="../../xslt/search-coll-entries2html.xsl"/>

    <xsl:param name="queryfile"/>

    <xsl:template match="query-results">
        <table class="hitlist" id="{@collID}" border="1">
            <xsl:call-template name="navigation">
                <xsl:with-param name="position" select="'top'"/>
            </xsl:call-template>
        <tr>
        <td class="hit" colspan="3">
          <ul class="hitlist">
            <xsl:apply-templates >
              <xsl:with-param name="showlang" select="./@showlang"/>
            </xsl:apply-templates>
          </ul>
        </td>
        </tr>
        </table>
    </xsl:template>
    
    <xsl:template name="navigation">
        <xsl:param name="position"/>
        <tr class="result-head" width="100%">
            <th class="nav{$position}" align="left" width="20%">
                <xsl:if test="@start &gt; 1">
                    <a href="{$queryfile}.xq?start={@start - @max}&amp;howmany={@max}&amp;showlang={@showlang}">
                        <i18n:text>Prev</i18n:text><br/>&lt;&lt;
                    </a>
                </xsl:if>
            </th>
            <th class="nav{$position}" align="center" width="60%">
                <i18n:text>DisplHits</i18n:text>
                <xsl:text> </xsl:text>
                <xsl:value-of select="@start"/> - <xsl:value-of select="@next - 1"/>
                <br/>
                (<i18n:text>TotalHits</i18n:text>: <xsl:value-of select="@hits"/>)
            </th>
            <th class="nav{$position}" align="right" width="20%">
                <xsl:if test="number(@next) &lt;= @hits">
                    <a href="{$queryfile}.xq?start={@next}&amp;howmany={@max}&amp;showlang={@showlang}">
                        <i18n:text>Next</i18n:text><br/>&gt;&gt;
                    </a>
                </xsl:if>

            </th>
        </tr>
    </xsl:template>
    
	<xsl:template match="entry">
        <xsl:param name="showlang"/>
        <li class="recordentry">
          <a>
		    <xsl:attribute name="href" >
		      <xsl:value-of select="concat('termrequest.xq?record=',@id)"/>
		    </xsl:attribute>
            <i18n:text>TermRecord</i18n:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="./@id"/>
          </a>,
          <xsl:apply-templates select="topicClass"/>
          <ul>
            <xsl:choose>
              <!-- Check whether all languages should be listed (the default): -->
              <xsl:when test="$showlang = 'all'">
                <xsl:apply-templates select="entryref">
                  <xsl:with-param name="langlist" select="'all'"/>
                  <xsl:with-param name="showlang" select="$showlang"/>
                </xsl:apply-templates>
              </xsl:when>

              <!-- If not, check the @xml:lang against the list of selected languages
                   when calling the template for each occurence of entryref -->
              <xsl:otherwise>

                <xsl:apply-templates select="entryref">
                  <xsl:with-param name="langlist" select="'selected'"/>
                  <xsl:with-param name="showlang" select="$showlang"/>
                </xsl:apply-templates>

                <li class="non-selected" ><span class="title"><i18n:text>OtherLang</i18n:text> </span>
                <xsl:apply-templates select="entryref">
                  <xsl:with-param name="langlist" select="'unselected'"/>
                  <xsl:with-param name="showlang" select="$showlang"/>
                </xsl:apply-templates>
                </li>

              </xsl:otherwise>
            </xsl:choose>
            <li>
              <form method="GET" action="add-new-lang-entry.xq" >
                <input type="hidden" name="id"   value="{@id}" />
                <input type="hidden" name="top"  value="{topicClass/@top}" />
                <input type="hidden" name="mid"  value="{topicClass/@mid}" />
                <input type="hidden" name="botm" value="{topicClass/@botm}"/>
                <input type="submit" value="NewLangBtn" i18n:attr="value"/>
              </form>
            </li>
          </ul>
        </li>
    </xsl:template>

    <xsl:template match="entryref">
        <xsl:param name="langlist"/>
        <xsl:param name="showlang"/>

        <xsl:choose>
          <!-- Process all languages: -->
          <xsl:when test="$showlang = 'all'
                          and
                          $langlist = 'all'">
          <li class="entryword">
			<a>
              <xsl:attribute name="href">
                <xsl:value-of select="concat('editlangentry.xq?',
                                     'entrylang=',
                                     @xml:lang,
                                     '&amp;request=',
                                        substring-before(
                                          substring-after(xi:include/@href,'xpointer('),
                                        ')')
                                      )"/>
              </xsl:attribute>
                <xsl:attribute name="title">
                  <xsl:value-of select="@xml:lang"/>
                </xsl:attribute>
                <xsl:attribute name="i18n:attr">title</xsl:attribute>

              <span class="langcode">
                <xsl:value-of select="@xml:lang"/>
              </span>
              <xsl:text> </xsl:text>
              <!-- The following expression transforms a string of type
                   terms-sme.xml#xpointer(//entry[@id='máná_biilastuollu\S'])
                   to the string 'máná biilastuollu' (without quotes). The
                   result string is used for user display. -->
              <xsl:choose>
                <xsl:when test="contains(xi:include/@href,'\')">
                  <xsl:value-of select="translate(
                                          substring(
                                            substring-after(
                                              substring-before(xi:include/@href, '\'),
                                            '@id='),
                                          2),
                                        '_', ' ')"/>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="translate(
                                          substring(
                                            substring-after(
                                              substring(xi:include/@href, 1, string-length(xi:include/@href) - 3),
                                            '@id='),
                                          2),
                                        '_', ' ')"/>
                </xsl:otherwise>
              </xsl:choose>
			</a>
          </li>
          </xsl:when>

          <!-- Process the selected languages: -->
          <xsl:when test="contains($showlang,./@xml:lang)
                          and
                          $langlist = 'selected'">
          <li class="entry">
			<a>
              <xsl:attribute name="href">
                <xsl:value-of select="concat('editlangentry.xq?',
                                     'entrylang=',
                                     @xml:lang,
                                     '&amp;request=',
                                        substring-before(
                                          substring-after(xi:include/@href,'xpointer('),
                                        ')')
                                      )"/>
              </xsl:attribute>

              <span class="langcode"><xsl:value-of select="@xml:lang"/></span>
              <xsl:text> </xsl:text>
              <!-- The following expression transforms a string of type
                   terms-sme.xml#xpointer(//entry[@id='máná_biilastuollu\S'])
                   to the string 'máná biilastuollu' (without quotes). The
                   result string is used for user display. -->
              <xsl:value-of select="translate(
                                      substring(
                                        substring-before(
                                          substring-after(xi:include/@href,'@id='),
                                        '\'),
                                      2),
                                    '_', ' ')"/>
			</a>
          </li>
          </xsl:when>

          <!-- Process the other languages, if any: -->
          <xsl:when test="not(contains($showlang,./@xml:lang) )
                          and
                          $langlist = 'unselected'">
          <span class="entryword">
			<a>
              <xsl:attribute name="href">
                <xsl:value-of select="concat('editlangentry.xq?',
                                     'entrylang=',
                                     @xml:lang,
                                     '&amp;request=',
                                        substring-before(
                                          substring-after(xi:include/@href,'xpointer('),
                                        ')')
                                      )"/>
              </xsl:attribute>
              <xsl:attribute name="title">
                <!-- The following expression transforms a string of type
                     terms-sme.xml#xpointer(//entry[@id='máná_biilastuollu\S'])
                     to the string 'máná biilastuollu' (without quotes). The
                     result string is used for user display. -->
                <xsl:value-of select="translate(
                                        substring(
                                          substring-before(
                                            substring-after(xi:include/@href,'@id='),
                                          '\'),
                                        2),
                                      '_', ' ')"/>
              </xsl:attribute>
              <span class="langcode"><xsl:value-of select="@xml:lang"/></span>
			</a>
            <xsl:text> </xsl:text>
          </span>
          </xsl:when>

        </xsl:choose>

    </xsl:template>
    
    <xsl:template match="topicClass">
		<topic>
			<top>
				<i18n:text i18n:catalogue="SD-class">
					<xsl:value-of select="@top"/>
				</i18n:text>
			</top>
			<xsl:if test="./@mid != ''">
				⇒
				<mid>
				    <i18n:text i18n:catalogue="SD-class">
						<xsl:value-of select="@mid"/>
					</i18n:text>
				</mid>
			</xsl:if>
			<xsl:if test="./@botm != ''">
				⇒
				<botm>
					<i18n:text i18n:catalogue="SD-class">
						<xsl:value-of select="@botm"/>
					</i18n:text>
				</botm>
			</xsl:if>
		</topic>
    </xsl:template>

</xsl:stylesheet>
