<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <!-- Adds common elements to the page, like changelogs
    <xsl:import href="../../../common.xsl"/> -->
    
    <!-- Adds the basic HTML wrapping based on the doc. structure provided by the XQuery -->
    <xsl:import href="../../xslt/edit-lang-entry2html.xsl"/>
    
	<xsl:template match="entry">
      <div class="entry">
        <h3><i18n:text><xsl:value-of select="@xml:lang"/></i18n:text></h3>

		<!-- Note that to get method="POST" to work correctly with UTF-8,
		     all three of method, accept-charset, and enctype should be specified -->
		<form action="update-lang-entry.xq"
		      method="POST"
		      accept-charset="UTF-8"
		      enctype="multipart/form-data" >

          <xsl:call-template name="common">
            <xsl:with-param name="lang" select="@xml:lang" />
            <xsl:with-param name="id"   select="@id" />
          </xsl:call-template >
          <hr/>

          <xsl:apply-templates select="senses">
            <xsl:with-param name="lang" select="@xml:lang" />
          </xsl:apply-templates >

          <hr/>
          <xsl:apply-templates select="log"/>
          <hr/>
          <button title="SaveButtonTitle" type="submit" i18n:attr="title"
                  value="savecommon" name="common" ><i18n:text>SaveEntry</i18n:text>
          </button>
          <xsl:text> </xsl:text>
          <button title="ResetButtonTitle" i18n:attr="title"
                  type="reset" ><i18n:text>ResetEntry</i18n:text>
          </button>

        </form>
      </div>
	</xsl:template>

	<xsl:template name="common">
		<xsl:param name="lang"/>
		<xsl:param name="id"/>
		<div class="common">

		  <input type="hidden" name="id" >
		    <xsl:attribute name="value">
				<xsl:value-of select="$id"/>
		    </xsl:attribute>
		  </input>
		  <input type="hidden" name="lang" >
		    <xsl:attribute name="value">
				<xsl:value-of select="$lang"/>
		    </xsl:attribute>
		  </input>

          <div class="entryword">
            <i18n:text>EntryWord/LexC upper</i18n:text>:
          </div>
          <input type="text" size="28" name="entry" >
            <xsl:attribute name="value">
        		<xsl:value-of select="@id"/>
            </xsl:attribute>
          </input>

          <div class="entryword">
            <i18n:text>LexC lower</i18n:text>:
          </div>
          <input type="text" size="28" name="spoken" >
            <xsl:attribute name="value">
        		<xsl:value-of select="./stem"/>
            </xsl:attribute>
          </input>

          <!-- Encapsulate the form fields in a table for prettier layout: -->
          <table class="entryEditor">

          <tr class="inflex">
            <td class="inflextitle"><i18n:text>InflEx</i18n:text>:</td>
            <td class="inflextxt">
              <!--input type="text" size="25" name="inflexmpl" >
                <xsl:attribute name="value">
                  <xsl:value-of select="infl/text()"/>
                </xsl:attribute>
              </input>
              <br/-->
              <xsl:apply-templates select="inflections">
                <xsl:with-param name="infl" select="infl/@lexc" />
              </xsl:apply-templates>
            </td>
          </tr>

		</table>

		</div>
	</xsl:template>

	<xsl:template match="senses">
		<xsl:param name="lang"/>
		<span class="sensetitle">
			<i18n:text>SensTitl</i18n:text>:
		</span>

		<ol class="senses">
		<xsl:for-each select="./sense">
			<li>
		  <div class="status">
				<xsl:apply-templates select=".">
					<xsl:with-param name="lang"     select="$lang" />
				</xsl:apply-templates> — 
				<xsl:value-of select="./@sem" />
		  </div>
			</li>
		</xsl:for-each>
		</ol>
	</xsl:template>

    <xsl:template match="sense">
		<xsl:param name="lang"/>
		<xsl:if test="@ref != ''">
			<xsl:text> </xsl:text>
			<a>
			    <xsl:attribute name="href">
					<xsl:value-of select="concat('get-term-record.xq?entrylang=',
									$lang,'&amp;record=',@ref)"/>
			    </xsl:attribute>
			    <xsl:value-of select="translate(@ref,'_',' ')"/>
			</a>
		</xsl:if>
    </xsl:template>

    <xsl:template match="inflections">
		<xsl:param name="infl"/>
		<select size="1" name="infl">
			<xsl:apply-templates>
				<xsl:with-param name="infl" select="$infl" />
			</xsl:apply-templates>
		</select>
    </xsl:template>

    <xsl:template match="inflection">
		<xsl:param name="infl"/>
        <option value="{@code}">
          <xsl:if test="$infl = @code">
            <xsl:attribute name="selected">1</xsl:attribute>
          </xsl:if>
          <xsl:value-of select="@code" />
        </option>
    </xsl:template>

    <xsl:template match="log">
      <span class="changelog"><i18n:text>NewComment</i18n:text>:</span>
      <textarea rows="3" cols="25" name="changecomment" />
      <div class="changelog" ><i18n:text>ChangeLog</i18n:text>:</div>
      <table class="changelog" >
        <tr>
          <th><i18n:text>ChangeWho</i18n:text>:</th>
          <th><i18n:text>ChangeWhen</i18n:text>:</th>
          <th><i18n:text>ChangeWhat</i18n:text>:</th>
        </tr>
        <xsl:apply-templates >
          <xsl:sort select="@when" order="descending" />
        </xsl:apply-templates >
      </table>
    </xsl:template>

</xsl:stylesheet>
