<?xml version="1.0" encoding="UTF-8"?>

<!-- Format term requests for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <!-- Adds the basic HTML wrapping based on the doc. structure provided by the XQuery -->
    <xsl:import href="../../xslt/get-term-record2html.xsl"/>

    <!-- Select the outer (encompassing) entry by requiring topicClass as
         its immediage child - this is the structure in the termcenter.xml file -->
	<xsl:template match="entry[sem]">
		<xsl:variable name="entry-ID" select="@id" />
		<div class="entry">
			<h2><i18n:text>TopicTitle</i18n:text>:</h2>
			<div class="topic">
				<span class="top">
					<i18n:text catalogue="propnoun-class"><xsl:value-of
					      select="local-name(./sem/child::*)"/></i18n:text>
				</span>
			</div>
			<xsl:for-each select="./langentry">
				<div class="lang">
					<h3><i18n:text><xsl:value-of select="@lang"/></i18n:text></h3>
					<xsl:call-template name="CommonTmpl" >
						<xsl:with-param name="lang" select="./@lang" />
					</xsl:call-template>
					<xsl:call-template name="senseTempl">
						<xsl:with-param name="lang" select="./@lang" />
						<xsl:with-param name="EntryID" select="$entry-ID" />
					</xsl:call-template>
					<xsl:apply-templates select="entry/changes" />
				</div>
			</xsl:for-each>
<!--
          <h3><i18n:text>CommonChang</i18n:text></h3>
          <xsl:apply-templates select="changes" /> -->
		</div>
	</xsl:template>

	<xsl:template name="senseTempl">
		<xsl:param name="lang"/>
        <xsl:param name="EntryID"/>
		<xsl:apply-templates select="//langentry[@lang=$lang]//sense[@ref=$EntryID]">
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template name="CommonTmpl">
		<xsl:param name="lang"/>
		<xsl:apply-templates select="//langentry[@lang=$lang]/entry" >
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>

    <!-- Make sure the parameters are passed on to the next template: -->
	<xsl:template match="langentry/entry">
		<xsl:param name="lang" />
		<span class="entryword">
		  <a>
            <xsl:attribute name="href">
                <xsl:value-of select="concat('edit-lang-entry.xq?entrylang=',
                				$lang,'&amp;record=',@id)"/>
            </xsl:attribute>
		    <xsl:value-of select="@id"/>
		  </a>
		</span>
		<xsl:apply-templates>
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>
    
	<xsl:template match="stem">
		<div class="stem">
		    <i18n:text>Stem</i18n:text>:
    		<xsl:apply-templates/>
		</div>
	</xsl:template>
    
	<xsl:template match="infl" name="infl">
		<div class="infl">
		    <i18n:text>InflCode</i18n:text>:
			<xsl:value-of select="@lexc"/>
		</div>
	</xsl:template>
    
	<xsl:template match="sense">
		<xsl:param name="lang"/>
		<sense status="{@status}">
			<xsl:if test="./def/text() != ''">
				<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
				<div class="def">
					<xsl:apply-templates select="./def" />
				</div>
			</xsl:if>
			<xsl:if test="./synonyms/synonym">
				<span class="syntitle"><i18n:text>SynHead</i18n:text></span>
				<div class="synonyms">
					<xsl:for-each select="./synonyms/synonym">
						<a>
							<xsl:attribute name="href">
								<xsl:value-of select="concat('edit-lang-entry.xq?entrylang=',
												$lang,'&amp;record=',@synref)"/>
							</xsl:attribute>
							<xsl:value-of select="translate(substring-before(@synref,'\'),'_',' ')"/>
						</a>
						<xsl:if test="./following-sibling::synonym">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</div>
			</xsl:if>
		</sense>
	</xsl:template>

</xsl:stylesheet>
