<?xml version="1.0"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exist="http://exist.sourceforge.net/NS/exist"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:xi="http://www.w3.org/2001/XInclude"
    version="1.0">

  <xsl:import href="../../xslt/search-coll-entries2html.xsl" />

  <xsl:param name="queryfile"/>

    <xsl:template match="query-results">
        <table class="hitlist" id="{@collID}" border="1">
            <xsl:call-template name="navigation">
                <xsl:with-param name="position" select="'top'"/>
            </xsl:call-template>
            <xsl:if test="./@showlang!='all'">
              <tr>
              <th>Entry word</th>
              <th>Lower</th>
              <th>Cont.</th>
              </tr>
            </xsl:if>
            <xsl:apply-templates >
              <xsl:with-param name="showlang" select="./@showlang"/>
              <xsl:with-param name="showhyph" select="./@showhyph"/>
            </xsl:apply-templates>
            <!--xsl:call-template name="navigation">
                <xsl:with-param name="position" select="'bottom'"/>
            </xsl:call-template-->
        </table>
    </xsl:template>

	<xsl:template match="entry">
      <xsl:param name="showlang"/>
      <xsl:param name="showhyph"/>
      <tr>
            <xsl:choose>
              <!-- Check whether all languages should be listed (the default): -->
              <xsl:when test="$showlang = 'all'">
                <td class="recordentry" colspan="2">
                  <a>
        		    <xsl:attribute name="href" >
        		      <xsl:value-of select="concat('get-term-record.xq?record=',@id)"/>
        		    </xsl:attribute>
                    <!--i18n:text>TermRecord</i18n:text>
                    <xsl:text> </xsl:text-->
                    <xsl:choose>
                      <xsl:when test="$showhyph = 'no'">
                        <xsl:value-of select="translate(@id, '^', '')" />
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:value-of select="@id" />
                      </xsl:otherwise>
                    </xsl:choose>
                  </a>
                </td>
                <td>
                  <xsl:apply-templates select="sem"/>
                </td>

                <xsl:apply-templates select="entryref">
                  <xsl:with-param name="showlang" select="$showlang"/>
                  <xsl:with-param name="showhyph" select="$showhyph"/>
                </xsl:apply-templates>
              </xsl:when>

              <!-- If not, check the @xml:lang against the list of selected languages
                   when calling the template for each occurence of entryref -->
              <xsl:otherwise>

                <xsl:apply-templates select="senses">
                  <xsl:with-param name="showlang" select="$showlang"/>
                  <xsl:with-param name="showhyph" select="$showhyph"/>
                </xsl:apply-templates>

                <!--
                li class="non-selected" ><span class="title"><i18n:text>OtherLang</i18n:text> </span>
                <xsl:apply-templates select="entryref">
                  <xsl:with-param name="langlist" select="'unselected'"/>
                  <xsl:with-param name="showlang" select="$showlang"/>
                </xsl:apply-templates>
                </li-->

              </xsl:otherwise>
            </xsl:choose>
      </tr>
    </xsl:template>

    <xsl:template match="senses">
        <xsl:param name="showlang"/>
        <xsl:param name="showhyph"/>

        <xsl:choose>
          <!-- Process all languages: -->
          <xsl:when test="$showlang = 'all' ">
          <li class="entryword">
			<a>
              <xsl:attribute name="href">
                <xsl:value-of select="concat('editlangentry.xq?',
                                     'entrylang=',
                                     @xml:lang,
                                     '&amp;record=',
                                        substring-before(
                                          substring-after(xi:include/@href,'xpointer('),
                                        ')')
                                      )"/>
              </xsl:attribute>
                <xsl:attribute name="title">
                  <xsl:value-of select="@xml:lang"/>
                </xsl:attribute>
                <xsl:attribute name="i18n:attr">title</xsl:attribute>

              <span class="langcode">
                <xsl:value-of select="@xml:lang"/>
              </span>
              <xsl:text> </xsl:text>
              <!-- The following expression transforms a string of type
                   terms-sme.xml#xpointer(//entry[@id='máná_biilastuollu\S'])
                   to the string 'máná biilastuollu' (without quotes). The
                   result string is used for user display. -->
                <xsl:apply-templates />
			</a>
          </li>
          <li>
            <form method="GET" action="newlangentry.xq" >
              <input type="hidden" name="id"   value="{@id}" />
              <input type="hidden" name="top"  value="{topicClass/@top}" />
              <input type="hidden" name="mid"  value="{topicClass/@mid}" />
              <input type="hidden" name="botm" value="{topicClass/@botm}"/>
              <input type="submit" value="NewLangBtn" i18n:attr="value"/>
            </form>
          </li>
          </xsl:when>

          <!-- Process the selected language: -->
          <xsl:otherwise>
          <td class="entry">
			<a>
              <xsl:attribute name="href">
                <xsl:value-of select="concat('edit-lang-entry.xq?',
                                     'entrylang=',
                                      $showlang,
                                     '&amp;record=',
                                      ../@id
                                      )"/>
              </xsl:attribute>
              <xsl:choose>
                <xsl:when test="$showhyph = 'no'">
                  <xsl:value-of select="translate(../@id, '^', '')" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="../@id" />
                </xsl:otherwise>
              </xsl:choose>
			</a>
          </td>
          <td>
              <xsl:choose>
                <xsl:when test="$showhyph = 'no'">
                  <xsl:value-of select="translate(../stem, '^', '')" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="../stem" />
                </xsl:otherwise>
              </xsl:choose>
          </td>
          <td>
              <xsl:value-of select="../infl/@lexc" />
          </td>
          </xsl:otherwise>


        </xsl:choose>

    </xsl:template>

    <xsl:template match="sem">
        <xsl:value-of select="name(./*)" />
    </xsl:template>

</xsl:stylesheet>
