<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <xsl:include href="hitlist2html.xsl"/>
    
	<xsl:template match="entry">
		<div class="entry">
			<h3><i18n:text><xsl:value-of select="@xml:lang"/></i18n:text></h3>
			<p>The entry exists!</p>
			<xsl:apply-templates >
				<xsl:with-param name="lang" select="@xml:lang" />
				<xsl:with-param name="id" select="@id" />
			</xsl:apply-templates >
		</div>
	</xsl:template>

	<xsl:template match="common">
		<xsl:param name="lang"/>
		<xsl:param name="id"/>
		<div class="common" >
		  <xsl:apply-templates>
			<xsl:with-param name="lang" select="$lang" />
			<xsl:with-param name="id" select="$id" />
		  </xsl:apply-templates >
		</div>
	</xsl:template>

	<xsl:template match="head">
		<xsl:param name="lang"/>
		<xsl:param name="id"/>
		<span class="entryword">
		    <xsl:apply-templates/>
		</span> - <span class="pos" title="POS" i18n:attr="title">
		    <xsl:value-of select="@pos"/>
		</span>
		<span>
		  <a>
		    <xsl:attribute name="href">
		      <xsl:value-of select="concat('editlangentry.xq?entrylang=',$lang,
		                                   '&amp;request=//entry[@id=&quot;',$id,'&quot;]')"/>
            </xsl:attribute>
            Edit this entry!
		  </a>
		</span>
		<xsl:if test="./following-sibling::infl">,
		  <xsl:apply-templates select="infl"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="infl" name="infl">
		<span class="infl" title="InflCode" i18n:attr="title">
			<xsl:value-of select="@major"/>
			<xsl:value-of select="@minor"/>
		</span>
		<div class="inflex">
			<span class="inflextitle"><i18n:text>InflEx</i18n:text>:</span>
			<span class="inflextxt">
				<xsl:apply-templates/>
			</span>
		</div>
	</xsl:template>

<!-- Comment until I've decided what to do with these elements:
	<xsl:template match="orth">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="qa">
		<xsl:apply-templates/>
	</xsl:template>
-->

	<xsl:template match="senses">
		<xsl:param name="lang"/>
		<span class="sensetitle">
			<i18n:text>SensTitl</i18n:text>:
		</span>
		<ol class="senses">
		<xsl:for-each select="./sense">
			<li>
				<xsl:apply-templates select="./topic" >
					<xsl:with-param name="href"    select="./@href" />
				</xsl:apply-templates>
				<xsl:apply-templates select=".">
					<xsl:with-param name="lang"    select="$lang" />
					<xsl:with-param name="status"  select="@status" />
					<xsl:with-param name="mainref" select="@mainref" />
				</xsl:apply-templates>
			</li>
		</xsl:for-each>
		</ol>
	</xsl:template>

    <xsl:template match="sense">
		<xsl:param name="lang"/>
		<xsl:param name="status"/>
		<xsl:param name="mainref"/>
		<div class="status">
			<i18n:text>StatTitle</i18n:text>:
			<span class="statustitle">
				<i18n:text><xsl:value-of select="$status"/></i18n:text>
			</span>
			<xsl:if test="$mainref != ''">
				<xsl:text> </xsl:text>
				<a>
				    <xsl:attribute name="href">
						<xsl:value-of select="concat('dictrequest.xq?entrylang=',
										$lang,'&amp;record=',$mainref)"/>
				    </xsl:attribute>
				    <xsl:value-of select="translate(substring-before($mainref,'\'),'_',' ')"/>
				</a>
			</xsl:if>
		</div>
		<xsl:if test="./def/text() != ''">
			<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
			<div class="def">
				<xsl:apply-templates select="./def" />
			</div>
		</xsl:if>
		<xsl:if test="./synonyms">
    			<span class="syntitle"><i18n:text>SynHead</i18n:text></span>
    			<div class="synonyms">
				<xsl:apply-templates select="./synonyms" />
    				<xsl:for-each select="./synonyms/synonym">
    					<a>
    						<xsl:attribute name="href">
    							<xsl:value-of select="concat('dictrequest.xq?entrylang=',
    											$lang,'&amp;record=',@synref)"/>
    						</xsl:attribute>
    						<xsl:value-of select="translate(substring-before(@synref,'\'),'_',' ')"/>
    					</a>
    					<xsl:if test="./following-sibling::synonym">
    						<xsl:text>, </xsl:text>
    					</xsl:if>
    				</xsl:for-each>
    			</div>
		</xsl:if>
    </xsl:template>

    <xsl:template match="topic">
		<xsl:param name="href"/>
		<a>
	    <xsl:attribute name="href">
	    		<xsl:value-of select="concat('termrequest.xq?record=',$href)"/>
	    </xsl:attribute>
		<span class="topic">
			<span class="top">
	    		<i18n:text i18n:catalogue="SD-class">
	    			<xsl:value-of select="top/@id"/>
	    		</i18n:text>
	    	</span>
	    	<xsl:if test="./mid/@id != ''">
	    		<span class="mid"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    				<xsl:value-of select="mid/@id"/>
	    			</i18n:text>
	    		</span>
	    		<xsl:if test="./botm/@id != ''">
	    			<span class="botm"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    					<xsl:value-of select="botm/@id"/>
	    				</i18n:text>
	    			</span>
	    		</xsl:if>
	    	</xsl:if>
		</span>
		</a>
    </xsl:template>

</xsl:stylesheet>
