<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <!-- Adds common elements to the page, like changelogs -->
    <xsl:include href="common.xsl"/>
    
    <!-- Adds the basic HTML wrapping based on the doc. structure provided by the XQuery -->
    <xsl:include href="hitlist2html.xsl"/>
    
	<xsl:template match="entry">
      <div class="entry">
        <h3><i18n:text><xsl:value-of select="@xml:lang"/></i18n:text></h3>

		<!-- Note that to get method="POST" to work correctly with UTF-8,
		     all three of method, accept-charset, and enctype should be specified -->
		<form action="savelangentry.xq"
		      method="POST"
		      accept-charset="UTF-8"
		      enctype="multipart/form-data" >

          <xsl:apply-templates >
            <xsl:with-param name="lang" select="@xml:lang" />
            <xsl:with-param name="id"   select="@id" />
          </xsl:apply-templates >

          <button title="SaveButtonTitle" type="submit" i18n:attr="title"
                  value="savecommon" name="common" ><i18n:text>SaveEntry</i18n:text>
          </button>
          <xsl:text> </xsl:text>
          <button title="ResetButtonTitle" i18n:attr="title"
                  type="reset" ><i18n:text>ResetEntry</i18n:text>
          </button>

        </form>
      </div>
	</xsl:template>

	<xsl:template match="common">
		<xsl:param name="lang"/>
		<xsl:param name="id"/>
		<div class="common">

		  <input type="hidden" name="id" >
		    <xsl:attribute name="value">
				<xsl:value-of select="$id"/>
		    </xsl:attribute>
		  </input>
		  <input type="hidden" name="lang" >
		    <xsl:attribute name="value">
				<xsl:value-of select="$lang"/>
		    </xsl:attribute>
		  </input>

          <!-- Encapsulate the form fields in a table for prettier layout: -->
          <table class="entryEditor">

          <tr class="entryword">
            <td><i18n:text>EntryWord</i18n:text>:</td>
            <td>
            <input type="text" size="25" name="entry" >
              <xsl:attribute name="value">
          		<xsl:value-of select="head/text()"/>
              </xsl:attribute>
            </input>
            </td>
          </tr>

          <tr class="pos">
            <td><i18n:text>POS</i18n:text>:</td>
            <td>
            <select size="1" name="pos">
                <option value="S">
                  <xsl:if test="head/@pos = ('' or 'S')">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">S</i18n:text>
                </option>
                <option value="A">
                  <xsl:if test="head/@pos = 'A'">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">A</i18n:text>
                </option>
                <option value="V">
                  <xsl:if test="head/@pos = 'V'">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">V</i18n:text>
                </option>
                <option value="Adv">
                  <xsl:if test="head/@pos = 'Adv'">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">Adv</i18n:text>
                </option>
                <option value="PP">
                  <xsl:if test="head/@pos = 'PP'">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">PP</i18n:text>
                </option>
                <option value="Pron">
                  <xsl:if test="head/@pos = 'Pron'">
                    <xsl:attribute name="selected">1</xsl:attribute>
                  </xsl:if>
                  <i18n:text catalogue="pos">Pron</i18n:text>
                </option>
             </select>
            </td>
          </tr>

          <tr class="entryword">
            <td><i18n:text>Pronounc</i18n:text>:</td>
            <td>
            <input type="text" size="25" name="spoken" >
              <xsl:attribute name="value">
          		<xsl:value-of select="./spoken"/>
              </xsl:attribute>
            </input>
            </td>
          </tr>

          <tr>
          <td class="infltitle"><i18n:text>InflCode</i18n:text>:</td>
          <td class="infl" title="InflCode" i18n:attr="title">
            <input type="text" size="3" name="inflmajor" >
              <xsl:attribute name="value">
          	  <xsl:value-of select="infl/@major"/>
              </xsl:attribute>
            </input>
            <xsl:text> </xsl:text>
            <input type="text" size="1" name="inflminor" >
              <xsl:attribute name="value">
          	  <xsl:value-of select="infl/@minor"/>
              </xsl:attribute>
            </input>
          </td>
          </tr>

          <tr class="inflex">
            <td class="inflextitle"><i18n:text>InflEx</i18n:text>:</td>
            <td class="inflextxt">
              <input type="text" size="25" name="inflexmpl" >
                <xsl:attribute name="value">
                  <xsl:value-of select="infl/text()"/>
                </xsl:attribute>
              </input>
            </td>
          </tr>

          <tr class="Orthography">
            <td class="OrthStatTitl"><i18n:text>OrthStatus</i18n:text>:</td>
            <td class="OrthStatTxt">

    		   <select size="1" name="orthstatus" >
    			 <option value="main">
                    <xsl:if test="orth/@status = ('main' or '')">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarMain</i18n:text></option>
    			 <option value="abbr">
                    <xsl:if test="orth/@status = 'abbr'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarAbbr</i18n:text></option>
    			 <option value="variant">
                    <xsl:if test="orth/@status = 'variant'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarVaria</i18n:text></option>
    			 <option value="false">
                    <xsl:if test="orth/@status = 'false'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarMissp</i18n:text></option>
    		   </select>

            </td>
          </tr>

          <tr>
            <td colspan="2" class="OrthVarTitl"><i18n:text>OrthVar</i18n:text>:</td>
          </tr>

            <tr>
              <td>
              <!-- Orthographical variant #1: -->
              <input type="text" size="15" name="orthvar1" >
                <xsl:attribute name="value">
                  <xsl:value-of select="translate(
                                            substring-before(
                                                  orth/variant[1]/@variantref,
                                                  '\'),
                                            '_',' ')"/>
                </xsl:attribute>
              </input>
              </td>
              <td>
    		   <select name="orthvartyp1" size="1" >
    			 <option value="abbr">
                    <xsl:if test="orth/variant[1]/@status = ('abbr' or '')">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarAbbr</i18n:text></option>
    			 <option value="variant">
                    <xsl:if test="orth/variant[1]/@status = 'variant'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarVaria</i18n:text></option>
    			 <option value="false">
                    <xsl:if test="orth/variant[1]/@status = 'false'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarMissp</i18n:text></option>
    		   </select>
              </td>
            </tr>

            <tr>
              <td>
              <!-- Orthographical variant #2: -->
              <input type="text" size="15" name="orthvar2" >
                <xsl:attribute name="value">
                  <xsl:value-of select="translate(
                                            substring-before(
                                                  orth/variant[2]/@variantref,
                                                  '\'),
                                            '_',' ')"/>
                </xsl:attribute>
              </input>
              </td>
              <td>
    		   <select name="orthvartyp2" size="1" >
    			 <option value="abbr">
                    <xsl:if test="orth/variant[2]/@status = 'abbr'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarAbbr</i18n:text></option>
    			 <option value="variant">
                    <xsl:if test="( orth/variant[2]/@status = ('' or 'variant') )
                                  or not (orth/variant[2])">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarVaria</i18n:text></option>
    			 <option value="false">
                    <xsl:if test="orth/variant[2]/@status = 'false'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarMissp</i18n:text></option>
    		   </select>
              </td>
            </tr>

            <tr>
              <td>
              <!-- Orthographical variant #3: -->
              <input type="text" size="15" name="orthvar3" >
                <xsl:attribute name="value">
                  <xsl:value-of select="translate(
                                            substring-before(
                                                  orth/variant[3]/@variantref,
                                                  '\'),
                                            '_',' ')"/>
                </xsl:attribute>
              </input>
              </td>
              <td>
    		   <select name="orthvartyp3" size="1" >
    			 <option value="abbr">
                    <xsl:if test="orth/variant[3]/@status = 'abbr'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarAbbr</i18n:text></option>
    			 <option value="variant">
                    <xsl:if test="orth/variant[3]/@status = 'variant'">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarVaria</i18n:text></option>
    			 <option value="false">
                    <xsl:if test="(orth/variant[3]/@status = ('' or 'false') )
                                  or not (orth/variant[3])">
                      <xsl:attribute name="selected">1</xsl:attribute>
                    </xsl:if>
    			   <i18n:text>OrthVarMissp</i18n:text></option>
    		   </select>
              </td>
            </tr>

          <tr class="QAChecked">
            <td class="QACheckedTitl"><i18n:text>QAChecked</i18n:text>:</td>
            <td class="QACheckedTxt">
            <table>
            <tr>
            <td width="40">
              <input type="radio" name="qachecked" value="true">
                <xsl:if test="qa/@checked = 'true'">
                  <xsl:attribute name="checked">1</xsl:attribute>
                </xsl:if>
              </input><i18n:text>QACheckedYes</i18n:text>
            </td>
            <td >
              <xsl:value-of select="qa/@who" />
              <xsl:if test="qa/@when">
                <xsl:text>, </xsl:text>
                <i18n:date-time
                    src-pattern="yyyyMMddhhmmss"
                        pattern="yyyy-MM-dd HH.mm">
                  <xsl:value-of select="qa/@when" />
                </i18n:date-time>
              </xsl:if>
            </td>
            </tr>
            <tr>
            <td>
              <input type="radio" name="qachecked" value="false">
                <xsl:if test="qa/@checked = 'false'">
                  <xsl:attribute name="checked">1</xsl:attribute>
                </xsl:if>
              </input><i18n:text>QACheckedNo</i18n:text>
            </td>
            </tr>
            </table>
            </td>
          </tr>

		</table>

		</div>
	</xsl:template>

	<xsl:template match="senses">
		<xsl:param name="lang"/>
		<hr/>
		<span class="sensetitle">
			<i18n:text>SensTitl</i18n:text>:
		</span>
		<!-- Store the number of senses in a hidden field, to be used as limit value
		     when recursively processing all senses on update -->
        <input type="hidden" name="sensecount" >
          <xsl:attribute name="value">
            <xsl:value-of select="count(./sense)" />
          </xsl:attribute>
        </input>

		<ol class="senses">
		<xsl:for-each select="./sense">
			<li>
				<xsl:apply-templates select="./topicClass" >
					<xsl:with-param name="idref"    select="./@idref" />
					<xsl:with-param name="position" select="position()" />
				</xsl:apply-templates>
				<xsl:apply-templates select=".">
					<xsl:with-param name="lang"     select="$lang" />
					<xsl:with-param name="status"   select="@status" />
					<xsl:with-param name="mainref"  select="@mainref" />
					<xsl:with-param name="position" select="position()" />
				</xsl:apply-templates>
			</li>
		</xsl:for-each>
		</ol>
	</xsl:template>

    <xsl:template match="sense">
		<xsl:param name="lang"/>
		<xsl:param name="status"/>
		<xsl:param name="mainref"/>
		<xsl:param name="position"/>
		  <div class="status">
			<i18n:text>StatTitle</i18n:text>:
			<span class="status">

                <input type="hidden" >
                  <xsl:attribute name="name">
                    <xsl:value-of select="concat('status-',$position)" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
                    <xsl:value-of select="$status" />
                  </xsl:attribute>
                </input>
              <xsl:if test="$status = 'syn'">
                <input type="hidden" >
                  <xsl:attribute name="name">
                    <xsl:value-of select="concat('mainref-',$position)" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
                    <xsl:value-of select="$mainref" />
                  </xsl:attribute>
                </input>
              </xsl:if>

				<i18n:text><xsl:value-of select="$status"/></i18n:text>
			</span>
			<xsl:if test="$mainref != ''">
				<xsl:text> </xsl:text>
				<a>
				    <xsl:attribute name="href">
						<xsl:value-of select="concat('dictrequest.xq?entrylang=',
										$lang,'&amp;record=',$mainref)"/>
				    </xsl:attribute>
				    <xsl:value-of select="translate(substring-before($mainref,'\'),'_',' ')"/>
				</a>
			</xsl:if>
		  </div>
			<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
			<div class="def">
			  <textarea rows="4" cols="30" >
			    <xsl:attribute name="name">
                  <xsl:value-of select="concat('def-',$position)" />
                </xsl:attribute>
                <xsl:value-of select="./def" />
              </textarea>
			</div>

			<span class="deftitle"><i18n:text>ExHead</i18n:text></span>
			<div class="def">
			  <textarea rows="2" cols="30" >
			    <xsl:attribute name="name">
                  <xsl:value-of select="concat('example-',$position)" />
                </xsl:attribute>
                <xsl:value-of select="./example" />
              </textarea>
			</div>

   			<div class="synonyms">

    		<span class="syntitle"><i18n:text>SynHead</i18n:text></span>

              <!-- Synonym #1: -->
              <input type="text" size="20" >
                <xsl:attribute name="value">
            		<xsl:value-of select="translate(
            		     substring-before(
            		         synonyms/synonym[1]/@synref,'\'),
            		            '_',' ')"/>
                </xsl:attribute>
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-syn-1')" />
                  </xsl:attribute>
              </input> -
              <span class="pos" title="POS" i18n:attr="title">
                <input type="text" size="1" >
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-synpos-1')" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
              		<xsl:value-of select="substring-after(synonyms/synonym[1]/@synref,'\')"/>
                  </xsl:attribute>
                </input>
              </span>
              <br/> <!-- Remove when CSS is updated -->

              <!-- Synonym #2: -->
              <input type="text" size="20" >
                <xsl:attribute name="value">
            		<xsl:value-of select="translate(
            		     substring-before(
            		         synonyms/synonym[2]/@synref,'\'),
            		            '_',' ')"/>
                </xsl:attribute>
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-syn-2')" />
                  </xsl:attribute>
              </input> -
              <span class="pos" title="POS" i18n:attr="title">
                <input type="text" size="1" >
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-synpos-2')" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
              		<xsl:value-of select="substring-after(synonyms/synonym[2]/@synref,'\')"/>
                  </xsl:attribute>
                </input>
              </span>
              <br/> <!-- Remove when CSS is updated -->

              <!-- Synonym #3: -->
              <input type="text" size="20" >
                <xsl:attribute name="value">
            		<xsl:value-of select="translate(
            		     substring-before(
            		         synonyms/synonym[3]/@synref,'\'),
            		            '_',' ')"/>
                </xsl:attribute>
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-syn-3')" />
                  </xsl:attribute>
              </input> -
              <span class="pos" title="POS" i18n:attr="title">
                <input type="text" size="1" >
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-synpos-3')" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
              		<xsl:value-of select="substring-after(synonyms/synonym[3]/@synref,'\')"/>
                  </xsl:attribute>
                </input>
              </span>
              <br/> <!-- Remove when CSS is updated -->

              <!-- Synonym #4: -->
              <input type="text" size="20" >
                <xsl:attribute name="value">
            		<xsl:value-of select="translate(
            		     substring-before(
            		         synonyms/synonym[4]/@synref,'\'),
            		            '_',' ')"/>
                </xsl:attribute>
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-syn-4')" />
                  </xsl:attribute>
              </input> -
              <span class="pos" title="POS" i18n:attr="title">
                <input type="text" size="1" >
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-synpos-4')" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
              		<xsl:value-of select="substring-after(synonyms/synonym[4]/@synref,'\')"/>
                  </xsl:attribute>
                </input>
              </span>
              <br/> <!-- Remove when CSS is updated -->

              <!-- Synonym #5: -->
              <input type="text" size="20" >
                <xsl:attribute name="value">
            		<xsl:value-of select="translate(
            		     substring-before(
            		         synonyms/synonym[5]/@synref,'\'),
            		            '_',' ')"/>
                </xsl:attribute>
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-syn-5')" />
                  </xsl:attribute>
              </input> -
              <span class="pos" title="POS" i18n:attr="title">
                <input type="text" size="1" >
  			    <xsl:attribute name="name">
                    <xsl:value-of select="concat('sense-', $position,'-synpos-5')" />
                  </xsl:attribute>
                  <xsl:attribute name="value">
              		<xsl:value-of select="substring-after(synonyms/synonym[5]/@synref,'\')"/>
                  </xsl:attribute>
                </input>
              </span>
              <br/> <!-- Remove when CSS is updated -->

            </div>
    </xsl:template>

    <xsl:template match="topicClass">
		<xsl:param name="idref"/>
		<xsl:param name="position"/>

        <input type="hidden" >
          <xsl:attribute name="name">
            <xsl:value-of select="concat('topic-', $position,'-ref')" />
          </xsl:attribute>
          <xsl:attribute name="value">
      		<xsl:value-of select="$idref"/>
          </xsl:attribute>
        </input>
        <input type="hidden" >
          <xsl:attribute name="name">
            <xsl:value-of select="concat('top-', $position)" />
          </xsl:attribute>
          <xsl:attribute name="value">
      		<xsl:value-of select="@top"/>
          </xsl:attribute>
        </input>
        <input type="hidden" >
          <xsl:attribute name="name">
            <xsl:value-of select="concat('mid-', $position)" />
          </xsl:attribute>
          <xsl:attribute name="value">
      		<xsl:value-of select="@mid"/>
          </xsl:attribute>
        </input>
        <input type="hidden" >
          <xsl:attribute name="name">
            <xsl:value-of select="concat('botm-', $position)" />
          </xsl:attribute>
          <xsl:attribute name="value">
      		<xsl:value-of select="@botm"/>
          </xsl:attribute>
        </input>

		<a>
	    <xsl:attribute name="href">
	    		<xsl:value-of select="concat('termrequest.xq?record=',$idref)"/>
	    </xsl:attribute>
		<span class="topic">
			<span class="top">
	    		<i18n:text i18n:catalogue="SD-class">
	    			<xsl:value-of select="@top"/>
	    		</i18n:text>
	    	</span>
	    	<xsl:if test="./@mid != ''">
	    		<span class="mid"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    				<xsl:value-of select="@mid"/>
	    			</i18n:text>
	    		</span>
	    		<xsl:if test="./@botm != ''">
	    			<span class="botm"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    					<xsl:value-of select="@botm"/>
	    				</i18n:text>
	    			</span>
	    		</xsl:if>
	    	</xsl:if>
		</span>
		</a>
    </xsl:template>

    <xsl:template match="changes">
      <hr/>
      <span class="changelog"><i18n:text>NewComment</i18n:text>:</span>
      <textarea rows="2" cols="30" name="changecomment" />
      <div class="changelog" ><i18n:text>ChangeLog</i18n:text>:</div>
      <table class="changelog" >
        <tr>
          <th><i18n:text>ChangeWho</i18n:text>:</th>
          <th><i18n:text>ChangeWhen</i18n:text>:</th>
          <th><i18n:text>ChangeWhat</i18n:text>:</th>
        </tr>
        <xsl:apply-templates >
          <xsl:sort select="@when" order="descending" />
        </xsl:apply-templates >
      </table>
    </xsl:template>

</xsl:stylesheet>
