xquery version "1.0";

declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

import module namespace ristenutil="http://www.risten.no/shared/util"
                        at "../xquery/ristenutil.xqm";

(: Create filter expression from query term, field and mode :)
declare function local:filter-expr($record as xs:string) as xs:string
{
    let $t := concat("'", $record, "'")
    return
        concat("@id = ", $t)
};

(: Assemble the query string :)
declare function local:build-query($record    as xs:string,
                                   $entrylang as xs:string,
                                   $collID    as xs:string)
as xs:string
{
    let $expr := local:filter-expr($record),
		$doc  := ristenutil:get-doc($collID, $entrylang)
    return
        concat("for $r in document('", $doc, "')//entry[",
            $expr, "] return $r")
};

(: Modify the query results before display:  :)
declare function local:display($entrylang as xs:string,
                               $collID as xs:string,
                               $hits as node()+)
as element()
{
	let $entry := item-at($hits, 1),
		$common  := $entry/common,
		$senses  := $entry/senses
	return
		<entry xml:lang="{$entrylang}" collID="{$collID}">
		{$common}
		{$senses}
		</entry>
};

(: Main function - retrieves some request attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
	let $record    := request:get-parameter("record", ""),
		$entrylang := request:get-parameter("entrylang", ""),
		$collection := request:get-parameter("collection", "")
    return
        if(string-length($record) = 0) then
                <p>WARNING: There was an error with this request!
                   Please check with the webmaster. <small>Cause:
                   No request record value.</small>
                </p>
        else
            let $query := local:build-query($record, $entrylang,$collection),
                $hits := util:eval( $query )
            return
                if (empty($hits)) then (
                    <p>ERROR! Record {$record} not found!</p>,
                    <p>Your language: {$entrylang}</p>,
                    <p>Your collection: {$collection}</p>,
                    <p>Your request: {$record}</p>,
                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p> )
                else (
(:                    <p><small>Your search query:<br/>
                    <query class="hidden">{$query}</query>
                    </small></p>
                    , :)
                    local:display($entrylang, $collection, $hits)
                    )
};

<document>
	<body>
        <header>
          <style href="risten_query_terms_SD-terms.css"/>
        </header>
        <section title="DictTitle"
                 collID='{request:get-parameter("collection", "")}'
                 colltype='{request:get-parameter("colltype", "")}'>
            { let $start := util:system-time() return
				(
					local:main(),
            		  <p class="srchtime">
                        <i18n:translate>
                          <i18n:text>SearchTime</i18n:text>
                          <i18n:param type="number" pattern="#.##" >
                            { round-half-to-even( seconds-from-duration(
                              util:system-time()-$start) , 3)}
                          </i18n:param>
             	       </i18n:translate>
                     </p>
				)
			}
        </section>
    </body>
</document>
