xquery version "1.0";

declare namespace session="http://exist-db.org/xquery/session";
declare namespace request="http://exist-db.org/xquery/request";
declare namespace util="http://exist-db.org/xquery/util";
declare namespace i18n="http://apache.org/cocoon/i18n/2.1";

import module namespace ristenutil="http://www.risten.no/shared/util" at "../xquery/ristenutil.xqm";

(: Map query field parameter to xpath selection :)
declare function local:query-field($field as xs:string) as xs:string
{
    if ($field = "head") then
        "common/head"
    else if ($field = "def") then
        "senses/sense/def"
    else
        "."
};

(: Create filter expression from query term, field and mode,
   and add a classification filter if specified :)
declare function local:filter-expr($term  as xs:string,
                                $field as xs:string,
                                $mode  as xs:string) as xs:string
{
    let $class    := request:get-parameter("class", "all")

    let $c := if ($class = 'all') then ".//@top &amp;= '*'"
              else if (contains($class, '-') ) then
                   concat(".//@botm &amp;= '", substring-after($class, '-'), "'" )
                   else if ( string-length($class) = 1) then
                          concat(".//@top &amp;= '", $class, "'" )
                        else
                          concat(".//@mid &amp;= '", $class, "'" )

    let $f  := local:query-field($field),
        $t  := concat("'", $term, "'"),
        $t2 := replace($term,"\?",".?"),
        $t3 := replace($t2,"\*",".*"),
        $t4 := replace($t3,"\(","\("),
        $t5 := replace($t4,"\)","\)"),
        $ttrad := concat("'^", $t5, "'")

    let $termsearch :=
        if ($mode = "trad") then
            concat("matches(", $f, ", ", $ttrad, ")")
        else if ($mode = "near") then
            concat("near(", $f, ", ", $t, ")")
        else if ($mode = "exact") then
            concat($f, " = ", $t)
        else
            concat($f, " &amp;= ", $t)

    return
        (: Removed the condition $term = '*', since querying the entire db seems
           acceptably fast - orig. condition was: $term = '*' or $term = '' :)
        if ($term = '' ) then
          $c
        else if ( $class = 'all') then
            $termsearch
          else
            concat($termsearch, " and ", $c)
};

(: Map order parameter to xpath for order by clause :)
(: Since the ordering element is not selectable, this function does
   not make any sense any more, but I'll keep it for now just in case. :)
declare function local:order-expr($field as xs:string) as xs:string
{
	if ($field = "head") then
		"common/head"
	else
		"common/qa, $r/common/head"
};

(: Assemble the query string :)
declare function local:build-query($srchcoll  as xs:string,
                                   $srchlang as xs:string+,
                                   $class    as xs:string,
                                   $term     as xs:string,
                                   $orderby  as xs:string)
                                 as xs:string
{
    let $field := request:get-parameter("field", "any"),
        $mode  := request:get-parameter("mode", "all"),
		$expr  := local:filter-expr($term, $field, $mode),
		$collID := tokenize($srchcoll, '/')[last()]
    return
   	  if ($srchlang = "all") then

        concat("for $r in collection('",
            $srchcoll,
            "')//entry[",
            $expr,
       	    "]/senses/sense order by $r/../../",
       	    local:order-expr($orderby),
       	    " collation '?lang=sme-SE' return ",
       	    "let $doc  := util:document-name($r) return ",
       	    "<superentry recid='{$r/@idref}' doc='{$doc}'>",
       	    "{$r/../..}</superentry>")

      else
        let $docs  := ristenutil:langs-to-docs($collID, $srchlang),
            $docstring := string-join($docs, ','),

      		$query := concat("for $r in document(",
      		        $docstring,
      		        ")//entry[",
            		$expr,
            		"]/senses/sense order by $r/",
            		local:order-expr($orderby),
            		" collation '?lang=sme-SE' return ",
               	    "let $doc  := util:document-name($r) return ",
               	    "<superentry recid='{$r/@idref}' doc='{$doc}'>",
            		"{$r/../..}</superentry>")
        return $query
};

(: Present an overview of query results :)
declare function local:displayHitlist($hits as node()+, $srchcoll as xs:string)
as element()
{
    let $count := count($hits),
        $max   := request:get-parameter("howmany", "10") cast as xs:int,
        $start := request:get-parameter("start", "1") cast as xs:int,
        $end   := if ($start + $max - 1 < $count) then $start + $max - 1 else $count

    return
        <query-results collection="{$srchcoll}" hits="{$count}"
            start="{$start}" next="{$end + 1}" max="{$max}">
            {
              for $p in $start to $end
              return
                let $current := item-at($hits, $p)
                return $current
            }
        </query-results>
};

(: Main function - retrieves some request and session attributes,
   forks further processing to other defined functions depending
   on the retrieved values :)
declare function local:main() as element()+
{
    let $term     := request:get-parameter("term", ""),  (: default value must be "" :)
        $srchlang := request:get-parameter("showlang","all"),
		$srchcoll := request:get-parameter("srchcoll",""), (: the collection path :)
		$class    := request:get-parameter("class", ""), (: default value must be "" :)
		$sort-key := "head"

	let $session-results := concat($srchcoll, "-results"),
	    $session-query   := concat($srchcoll, "-query")

	let $previous := session:get-attribute($session-results),
		$queryOld := session:get-attribute($session-query)

(: DEBUG ONLY: :)
    let $coll     := request:get-parameter("coll","all"),
		$params   := request:get-parameter-names(),
		$session  := session:get-attribute-names(),
        $iteration := request:get-parameter("iteration","")

    return
        if(string-length($term) = 0 and string-length($class) = 0) then
			if (exists($previous)) then
			(
(: DEBUG output:
			    <p><small>Your document path: {$srchcoll}<br/>
                Your $lang string: {$srchlang}<br/>
                Your $class string: {$class}<br/>
                Your session attributes: {$session}<br/>
                Your query filter/old query:<br/>
                {$queryOld}
                </small></p>,
                <p class="searchterm">
                <i18n:text>UrSrchTrm</i18n:text>: «{$term}»</p>
                , :)
                local:displayHitlist($previous, $srchcoll)
            )
			else
				<p><i18n:text>ErrorTimeOut</i18n:text></p>
        else
	let $query := local:build-query($srchcoll, $srchlang, $class, $term, $sort-key)
        
            let $hits := util:eval( $query ),
                $s := session:set-attribute($session-results, $hits),
                $u := session:set-attribute($session-query,   $query)
            return
                if (empty($hits)) then
                    (
                    <query-results collection="{$srchcoll}" hits="0"
                        start="0" next="1" max="0">
                      <i18n:text>NoHit</i18n:text> «{$term}»!
                    </query-results>
(: DEBUG only - output some extra info
                    ,
                    <p><small>Your document path: {$srchcoll}<br/>
					Your $lang string: {$srchlang}<br/>
					Your $class string: {$class}<br/>
					Your session attributes: {$session}<br/>
					Your query filter/old query:<br/>
					{$queryOld}<br/>
					Your complete search query:<br/>
					{$query}
					</small></p> :)
					)
                else (
(: DEBUG only - output some extra info :)
					<p><small>Your document path ($srchcoll): {$srchcoll}<br/>
					Your $lang string: {$srchlang}<br/>
					Your $class string: {$class}<br/>
					Your session attributes: {$session}<br/>
					Your request parameters: {$params}<br/>
					Frame iteration: {$iteration}<br/>
					Your query filter/old query:<br/>
					{$queryOld}<br/>
					Your complete search query:<br/>
					{$query}
					</small></p>,
					<p class="searchterm">
					<i18n:text>UrSrchTrm</i18n:text>: «{$term}»</p>
					,
					local:displayHitlist($hits, $srchcoll)
					)
};

let $collelements := tokenize(request:get-parameter("srchcoll",""),'/'),
    $coll := $collelements[last()],
    $type := $collelements[last()-1]
return
  <section id="{$coll}" type="{$type}" title="coll-short:{$coll}" i18n:attr="title">
    <header>
      <style href="risten_query_terms_SD-terms_search-coll-entries.css"/>
    </header>
      { let $start := util:system-time() return
      	(
   	      local:main(),
          <p class="srchtime">
          { round-half-to-even( seconds-from-duration(
            util:system-time()-$start) , 3)}
          </p>
      	)
      }
  </section>
