<?xml version="1.0" encoding="UTF-8"?>

<!-- Format query results for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exist="http://exist.sourceforge.net/NS/exist"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <xsl:import href="../../xslt/search-coll-entries2html.xsl"/>

    <xsl:param name="shortcolls"/>
    <xsl:param name="longcolls"/>

    <xsl:template match="query-results">
      <table id="{../@id}" hits="{@hits}">
        <caption>
            <i18n:text catalogue="{$longcolls}">
              <xsl:value-of select="../@id"/>
            </i18n:text>
        </caption>
        <xsl:call-template name="navigation">
            <xsl:with-param name="position" select="'top'"/>
        </xsl:call-template>
        <tr>
          <td colspan="3">
            <xsl:choose>
              <xsl:when test="@hits = 0">
                <xsl:attribute name="class">nohit</xsl:attribute>
                <xsl:apply-templates/>
              </xsl:when>
              <xsl:otherwise>
                <table>
                  <xsl:apply-templates/>
                </table>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </table>
    </xsl:template>

    <xsl:template match="superentry">
      <xsl:variable name="recid" select="@recid"/>
      <tr>
        <xsl:choose>
            <xsl:when test="position() mod 2 = 0">
                <xsl:attribute name="class">tbleven</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="class">tblodd</xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
        <td class="lang">
          <xsl:attribute name="title">messages:<xsl:value-of
                       select="substring-after(substring-before(@doc,'.'), '-')"/>
          </xsl:attribute>
          <xsl:attribute name="i18n:attr">title</xsl:attribute>
          <xsl:value-of select="substring-after(substring-before(@doc,'.'), '-')"/>
        </td>
        <td class="entry">
          <a href="get-term-record.xq?record={@recid}&amp;collection={../../@id}&amp;colltype={../../@type}">
			<xsl:attribute name="class">
			  <xsl:choose>
			    <!-- light green -->
			    <xsl:when test=".//sense[@idref = $recid]/@status = 'main'">main</xsl:when>
			    <!-- light yellow -->
			    <xsl:when test=".//sense[@idref = $recid]/@status = 'syn'" >syn</xsl:when>
			  </xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="title">hitlist:<xsl:value-of
			 select=".//sense[@idref = $recid]/@status"/></xsl:attribute>
			<xsl:attribute name="i18n:attr">title</xsl:attribute>
            <xsl:value-of select="entry/common/head"/>
          </a>
          <span class="topic">
            <xsl:text> </xsl:text>
            <xsl:apply-templates select=".//sense[@idref = $recid]/topicClass"/>
          </span>
        </td>
      </tr>
    </xsl:template>

    <xsl:template match="topicClass">
		<span class="top">
    		<i18n:text i18n:catalogue="SD-class">
    			<xsl:value-of select="@top"/>
    		</i18n:text>
    	</span>
    	<xsl:if test="./mid/@id != ''">
    		<span class="mid">
    		    <i18n:text i18n:catalogue="SD-class">
    				<xsl:value-of select="@mid"/>
    			</i18n:text>
    		</span>
    	</xsl:if>
    	<xsl:if test="./botm/@id != ''">
    		<span class="botm">
    			<i18n:text i18n:catalogue="SD-class">
    				<xsl:value-of select="@botm"/>
    			</i18n:text>
    		</span>
    	</xsl:if>
    </xsl:template>

    <!--xsl:template match="p"/-->

    <xsl:template match="@*|node()" priority="-1">
      <xsl:copy><xsl:apply-templates select="@*|node()"/></xsl:copy>
    </xsl:template>

</xsl:stylesheet>
