<?xml version="1.0" encoding="UTF-8"?>

<!--+ Format term requests for display.
    | Term lookup formatting, code specific to the SD-terms collection.
    |
    | Version: $Id: get-term-record2html.xsl,v 1.1 2006/10/04 15:27:21 sjur Exp $
    +-->


<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <xsl:import href="../../xslt/get-term-record2html.xsl"/>

    <!-- Select the outer (encompassing) entry by requiring topicClass as
         its immediate child - this is the structure in the termcenter.xml file -->
	<xsl:template match="entry[topicClass]">
		<xsl:variable name="entry-ID" select="@id" />
		<div class="entry">
			<h2><i18n:text>TopicTitle</i18n:text>:</h2>
			<div class="topic">
				<span class="top">
					<i18n:text catalogue="SD-class"><xsl:value-of select="./topicClass/@top"/></i18n:text>
				</span>
				<xsl:if test="./topicClass/@mid != ''">
					<span class="mid">
						<i18n:text catalogue="SD-class"><xsl:value-of select="./topicClass/@mid"/></i18n:text>
					</span>
					<xsl:if test="./topicClass/@botm != ''">
						<span class="botm">
							<i18n:text catalogue="SD-class"><xsl:value-of select="./topicClass/@botm"/></i18n:text>
						</span>
					</xsl:if>
				</xsl:if>
			</div>
			<xsl:for-each select="./entryref">
			  <xsl:sort order="descending" select="@xml:lang" />
				<div class="lang">
					<h3><i18n:text><xsl:value-of select="@xml:lang"/></i18n:text></h3>
					<xsl:call-template name="CommonTmpl" >
						<xsl:with-param name="lang" select="./@xml:lang" />
					</xsl:call-template>
					<xsl:call-template name="senseTempl">
						<xsl:with-param name="lang" select="./@xml:lang" />
						<xsl:with-param name="EntryID" select="$entry-ID" />
					</xsl:call-template>
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>

	<xsl:template name="senseTempl">
		<xsl:param name="lang"/>
        <xsl:param name="EntryID"/>
		<xsl:apply-templates select="//entryref[@xml:lang=$lang]//sense[@idref=$EntryID]">
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template name="CommonTmpl">
		<xsl:param name="lang"/>
		<xsl:apply-templates select="//entryref[@xml:lang=$lang]/entry/common" >
			<xsl:with-param name="headID" select="//entryref[@xml:lang=$lang]/entry/@id" />
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>

    <!-- Make sure the parameters are passed on to the next template: -->
	<xsl:template match="common">
        <xsl:param name="headID" />
		<xsl:param name="lang" />
		<xsl:apply-templates>
			<xsl:with-param name="headID" select="$headID" />
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>
    
    <!-- Add the entry word, with POS and optional inflection;
         put an anchor around the entry word linking to the dictionary
         entry of it. -->
	<xsl:template match="head" >
        <xsl:param name="headID" />
		<xsl:param name="lang" />
<!--		<div class="statustitle">
    		<i18n:text>StatMain</i18n:text>
		</div> -->
		<span class="entryword">
		  <a>
            <xsl:attribute name="href">
                <xsl:value-of select="concat('get-dict-entry.xq?entrylang=',
                				             $lang,
                				             '&amp;record=',
                				             $headID,
                				             '&amp;collection=',
                				             ./ancestor::section/@collID,
                				             '&amp;colltype=',
                				             ./ancestor::section/@colltype)"/>
            </xsl:attribute>
		    <xsl:apply-templates/>
		  </a>
		</span> - <span class="pos" title="POS" i18n:attr="title">
		    <xsl:value-of select="@pos"/>
		</span>
		<xsl:if test="./following-sibling::infl">,
		   <xsl:apply-templates select="infl"/>
		</xsl:if>
	</xsl:template>
    
	<xsl:template match="orth">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="qa">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="infl" name="infl">
		<span class="infl" title="InflCode" i18n:attr="title">
			<xsl:value-of select="@major"/>
			<xsl:value-of select="@minor"/>
		</span>
		<xsl:if test="./text()">
          <div class="inflex">
          	<span class="inflextitle"><i18n:text>InflEx</i18n:text>:
          	</span>
          	<span class="inflextxt">
          		<xsl:apply-templates/>
          	</span>
          </div>
		</xsl:if>
	</xsl:template>
    
	<xsl:template match="sense">
		<xsl:param name="lang"/>
		<sense status="{@status}">
			<xsl:if test="./def/text() != ''">
				<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
				<div class="def">
					<xsl:apply-templates select="./def" />
				</div>
			</xsl:if>
			<xsl:if test="./synonyms/synonym">
				<span class="syntitle"><i18n:text>SynHead</i18n:text></span>
				<div class="synonyms">
					<xsl:for-each select="./synonyms/synonym">
						<a>
							<xsl:attribute name="href">
								<xsl:value-of
								     select="concat('get-dict-entry.xq?entrylang=',
												     $lang,
												    '&amp;record=',
												     @synref,
												    '&amp;collection=',
												     ancestor::section/@collID,
												    '&amp;colltype=',
												     ancestor::section/@colltype)"/>
							</xsl:attribute>
							<xsl:value-of select="translate(substring-before(@synref,'\'),'_',' ')"/>
						</a>
						<xsl:if test="./following-sibling::synonym">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</div>
			</xsl:if>
		</sense>
	</xsl:template>

</xsl:stylesheet>
