<?xml version="1.0" encoding="UTF-8"?>

<!-- Format dictionary entries for display -->

<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <xsl:import href="../../xslt/get-dict-entry2html.xsl"/>
    
	<xsl:template match="entry">
		<div class="entry">
			<h3><i18n:text><xsl:value-of select="@xml:lang"/></i18n:text></h3>
			<xsl:apply-templates >
				<xsl:with-param name="lang" select="@xml:lang" />
				<xsl:with-param name="collID" select="@collID" />
			</xsl:apply-templates >
		</div>
	</xsl:template>

	<xsl:template match="common">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="head">
		<span class="entryword">
		    <xsl:apply-templates/>
		</span> -
		<span class="pos" title="POS" i18n:attr="title">
		    <xsl:value-of select="@pos"/>
		</span>
		<xsl:if test="./following-sibling::infl">,
		</xsl:if>
		<xsl:apply-templates select="infl"/>
	</xsl:template>

	<xsl:template match="infl" name="infl">
		<span class="infl" title="InflCode" i18n:attr="title">
			<xsl:value-of select="@major"/>
			<xsl:value-of select="@minor"/>
		</span>
		<div class="inflex">
			<span class="inflextitle"><i18n:text>InflEx</i18n:text>:
			</span>
			<span class="inflextxt">
				<xsl:apply-templates/>
			</span>
		</div>
	</xsl:template>

<!-- Commented out until I've decided what to do with these elements:
	<xsl:template match="orth">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="qa">
		<xsl:apply-templates/>
	</xsl:template>
-->

	<xsl:template match="senses">
		<xsl:param name="lang"/>
		<xsl:param name="collID"/>
		<span class="sensetitle">
			<i18n:text>SensTitl</i18n:text>:
		</span>
		<ol class="senses">
		<xsl:for-each select="sense">
			<li>
			  <xsl:choose>
			  <xsl:when test="./topicClass">
				<xsl:apply-templates select="./topicClass" >
					<xsl:with-param name="href"    select="./@idref" />
					<xsl:with-param name="collID"  select="$collID" />
				</xsl:apply-templates>
			  </xsl:when>
			  <xsl:otherwise>
                <a> <!-- TERM RECORD link -->
                <xsl:attribute name="href">
                  <xsl:value-of select="concat('get-term-record.xq?record=',
                                                @idref,
                                               '&amp;collection=',
                                                $collID,
                                               '&amp;colltype=',
                                                ancestor::section/@colltype)"/>
                </xsl:attribute>
			      <span class="topic">Center Record:
			        <xsl:value-of select="@idref" />
			      </span>
			    </a>
			  </xsl:otherwise>
			  </xsl:choose>
              <xsl:apply-templates select=".">
                  <xsl:with-param name="lang"    select="$lang" />
                  <xsl:with-param name="status"  select="@status" />
                  <xsl:with-param name="mainref" select="@mainref" />
              </xsl:apply-templates>
			</li>
		</xsl:for-each>
		</ol>
	</xsl:template>

    <xsl:template match="sense">
		<xsl:param name="lang"/>
		<xsl:param name="status"/>
		<xsl:param name="mainref"/>
		<div class="status">
			<i18n:text>StatTitle</i18n:text>:
			<span class="status">
				<i18n:text><xsl:value-of select="$status"/></i18n:text>
			</span>
			<xsl:if test="$mainref != ''">
				<xsl:text> </xsl:text>
				<a> <!-- MAIN ENTRY link (from a synonym) -->
				    <xsl:attribute name="href">
						<xsl:value-of
						     select="concat('get-dict-entry.xq?entrylang=',
										     $lang,
                                            '&amp;record=',
										     $mainref,
                                            '&amp;collection=',
                                             ancestor::section/@collID,
                                            '&amp;colltype=',
                                             ancestor::section/@colltype)"/>
				    </xsl:attribute>
				    <xsl:value-of select="translate(substring-before($mainref,'\'),'_',' ')"/>
				</a>
			</xsl:if>
		</div>
		<xsl:if test="./def/text() != ''">
			<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
			<div class="def">
				<xsl:apply-templates select="./def" />
			</div>
		</xsl:if>
		<xsl:if test="./synonyms">
    			<span class="syntitle"><i18n:text>SynHead</i18n:text></span>
    			<div class="synonyms">
				<xsl:apply-templates select="./synonyms" />
    				<xsl:for-each select="./synonyms/synonym">
    					<a> <!-- SYNONYM link -->
    						<xsl:attribute name="href">
						<xsl:value-of
						     select="concat('get-dict-entry.xq?entrylang=',
										     $lang,
										    '&amp;record=',
										     @synref,
                                            '&amp;collection=',
                                             ancestor::section/@collID,
                                            '&amp;colltype=',
                                             ancestor::section/@colltype)"/>
    						</xsl:attribute>
    						<xsl:value-of
    						     select="translate(substring-before(@synref,'\'),'_',' ')"/>
    					</a>
    					<xsl:if test="./following-sibling::synonym">
    						<xsl:text>, </xsl:text>
    					</xsl:if>
    				</xsl:for-each>
    			</div>
		</xsl:if>
    </xsl:template>

    <xsl:template match="topicClass">
		<xsl:param name="href"/>
		<xsl:param name="collID"/>
		<a> <!-- TERM RECORD link -->
	    <xsl:attribute name="href">
            <xsl:value-of select="concat('get-term-record.xq?record=',
                                          $href,
                                         '&amp;collection=',
                                          $collID,
                                         '&amp;colltype=',
                                          ancestor::section/@colltype)"/>
	    </xsl:attribute>
		<span class="topic">
			<span class="top">
	    		<i18n:text i18n:catalogue="SD-class">
	    			<xsl:value-of select="@top"/>
	    		</i18n:text>
	    	</span>
	    	<xsl:if test="@mid != ''">
	    		<span class="mid"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    				<xsl:value-of select="@mid"/>
	    			</i18n:text>
	    		</span>
	    		<xsl:if test="@botm != ''">
	    			<span class="botm"> ⇒ <i18n:text i18n:catalogue="SD-class">
	    					<xsl:value-of select="@botm"/>
	    				</i18n:text>
	    			</span>
	    		</xsl:if>
	    	</xsl:if>
		</span>
		</a>
    </xsl:template>

</xsl:stylesheet>
