<?xml version="1.0" encoding="UTF-8"?>

<!--+ Format term requests for display.
    | Term lookup formatting, code specific to the SD-terms collection.
    |
    | Version: $Id: get-term-record2html.xsl,v 1.2 2006/10/05 13:30:37 sjur Exp $
    +-->


<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    version="1.0">
    
    <xsl:import href="../../xslt/get-term-record2html.xsl"/>

    <!-- Select the outer (encompassing) entry by requiring topicClass as
         its immediate child - this is the structure in the termcenter.xml file -->
	<xsl:template match="entry[langentry]">
		<xsl:variable name="entry-ID" select="@id" />
		<div class="entry">
			<h2><i18n:text>TopicTitle</i18n:text>:</h2>
			<div class="topic">
				<span class="top">
					<i18n:text catalogue="propnouns"><xsl:value-of select="name(sem/*)"/></i18n:text>
				</span>
			</div>
			<xsl:for-each select="./langentry">
			  <xsl:sort order="descending" select="@lang" />
				<div class="lang">
					<h3><i18n:text><xsl:value-of select="@lang"/></i18n:text></h3>
					<xsl:apply-templates >
						<xsl:with-param name="lang" select="@lang" />
						<xsl:with-param name="entry-ID" select="$entry-ID" />
					</xsl:apply-templates>
				</div>
			</xsl:for-each>
		</div>
	</xsl:template>

	<xsl:template match="langentry">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="langentry/entry">
		<xsl:param name="lang"/>
		<xsl:param name="entry-ID"/>
		<span class="entryword">
		  <a>
            <xsl:attribute name="href">
                <xsl:value-of select="concat('get-dict-entry.xq?entrylang=',
                				             $lang,
                				             '&amp;record=',
                				             @id,
                				             '&amp;collection=',
                				             ./ancestor::section/@collID,
                				             '&amp;colltype=',
                				             ./ancestor::section/@colltype)"/>
            </xsl:attribute>
		    <xsl:value-of select="@id"/>
		  </a>
		</span> -
		<xsl:apply-templates select="infl" />
		<xsl:apply-templates select="stem" />
        <xsl:call-template name="senseTempl">
            <xsl:with-param name="lang" select="@lang" />
            <xsl:with-param name="EntryID" select="$entry-ID" />
        </xsl:call-template>
	</xsl:template>

	<xsl:template match="infl" name="infl">
		<span class="infl" title="InflCode" i18n:attr="title">
			<xsl:value-of select="@lexc"/>
		</span>
	</xsl:template>

	<xsl:template match="stem">
		<div class="stem">
		   <i18n:text>Stem</i18n:text>:
		   <xsl:apply-templates />
		</div>
	</xsl:template>

    <!-- The sense part is really made for SD-terms, and will have to be revised. But this should
         be an ok start. -->
	<xsl:template name="senseTempl">
		<xsl:param name="lang"/>
        <xsl:param name="EntryID"/>
		<xsl:apply-templates select="//entryref[@lang=$lang]//sense[@ref=$EntryID]">
			<xsl:with-param name="lang" select="$lang" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="sense">
		<xsl:param name="lang"/>
		<span class="{@status}">
			<xsl:if test="./def/text() != ''">
				<span class="deftitle"><i18n:text>DefHead</i18n:text></span>
				<div class="def">
					<xsl:apply-templates select="./def" />
				</div>
			</xsl:if>
			<xsl:if test="./synonyms/synonym">
				<span class="syntitle"><i18n:text>SynHead</i18n:text></span>
				<div class="synonyms">
					<xsl:for-each select="./synonyms/synonym">
						<a>
							<xsl:attribute name="href">
								<xsl:value-of
								     select="concat('get-dict-entry.xq?entrylang=',
												     $lang,
												    '&amp;record=',
												     @synref,
												    '&amp;collection=',
												     ancestor::section/@collID,
												    '&amp;colltype=',
												     ancestor::section/@colltype)"/>
							</xsl:attribute>
							<xsl:value-of select="translate(substring-before(@synref,'\'),'_',' ')"/>
						</a>
						<xsl:if test="./following-sibling::synonym">
							<xsl:text>, </xsl:text>
						</xsl:if>
					</xsl:for-each>
				</div>
			</xsl:if>
		</span>
	</xsl:template>

</xsl:stylesheet>
