(:
    Module: Dictionary menu building for the search interface.
            Returns all available dictionaries and terminology collections.
:)
module namespace dictmenu="http://www.risten.no/shared/dictmenu";

declare namespace util="http://exist-db.org/xquery/util";
declare namespace xmldb="http://exist-db.org/xquery/xmldb";

(: Get ID, coll, and classification ID for all available term collections. :)
(: Availability is checked against user credentials and access permisions. :)
(: Returns an element containing a sequence of empty elements with the following structure:
<termcolls count="">
   <termcoll id="" coll="" class="" />
   ...
</termcolls>
:)
declare function dictmenu:get-termcolls($user as xs:string) as element()
{
  	let $groups := if ($user = "all") then
  					/termmeta/id/text()
  				  else if ($user = "public") then
  				    /termmeta[public/text() eq "yes"]/id/text()
  				  else
  				    xmldb:get-user-groups($user)
    let $membergroups := count($groups)
    	
   	return
      <termcolls membergroups="{$membergroups}">
      {
        for $r in /termmeta
        let $coll := util:collection-name($r)
        let $collgroup := xmldb:get-group($coll)
        return
          (: we need to lower-case the ID string - groups are always lower-case :)
          if (contains( $groups, lower-case($r/id/text()) ) ) then
            <termcoll id="{$r/id/text()}" class="{$r/class/text()}" coll="{$coll}" />
            (: when the group is different from the Coll. ID, use the group of the collection :)
          else if (contains( $groups, $collgroup ) ) then
            <termcoll id="{$r/id/text()}" class="{$r/class/text()}" coll="{$coll}" />
          else if (contains( $groups, $r/id/text() ) ) then (: case: the user is 'all' or 'public' ->
                                                               $groups = list of id strings :)
            <termcoll id="{$r/id/text()}" class="{$r/class/text()}" coll="{$coll}" />
          else ()
      }
      </termcolls>
};

(: Get ID, and collection for all available dictionaries.                  :)
(: Availability is checked against user credentials and access permisions. :)
(: Returns an element containing a sequence of empty elements with the following structure:
<dictcolls count="">
   <dictcoll id="" coll="" />
   ...
</dictcolls>
:)
declare function dictmenu:get-dictcolls($user as xs:string) as element()
{
  	let $groups := if ($user = "all") then
  					/dictmeta/id/text()
  				  else if ($user = "public") then
  				    /dictmeta[public/text() eq "yes"]/id/text()
  				  else
  				    xmldb:get-user-groups($user)
    let $membergroups := count($groups)
    	
   	return
      <dictcolls membergroups="{$membergroups}">
      {
        for $r in /dictmeta
        let $coll := util:collection-name($r)
        let $collgroup := xmldb:get-group($coll)
        return
          (: we need to lower-case the ID string - groups are always lower-case :)
          if (contains( $groups, lower-case($r/id/text()) ) ) then
            <dictcoll id="{$r/id/text()}" coll="{$coll}" />
            (: when the group is different from the Coll. ID, use the group of the collection :)
          else if (contains( $groups, $collgroup ) ) then
            <dictcoll id="{$r/id/text()}" coll="{$coll}" />
          else if (contains( $groups, $r/id/text() ) ) then (: case: the user is 'all' or 'public' ->
                                                               $groups = list of id strings :)
            <dictcoll id="{$r/id/text()}" coll="{$coll}" />
          else ()
      }
      </dictcolls>
};

(: Get ID, and collection for all available classification schemes.        :)
(: Availability is checked against user credentials and access permisions. :)
(: Returns an element containing a sequence of empty elements with the following structure:
<classes count="">
   <class id="" coll="" />
   ...
</classes>
:)
declare function dictmenu:get-classcolls($user as xs:string) as element()
{
  	let $groups := if ($user = "all") then
  					/classmeta/id/text()
  				  else if ($user = "public") then
  				    /classmeta[public/text() eq "yes"]/id/text()
  				  else
  				    xmldb:get-user-groups($user)
    let $membergroups := count($groups)
    	
   	return
      <classes membergroups="{$membergroups}">
      {
        for $r in /classmeta
        let $coll := util:collection-name($r)
        let $collgroup := xmldb:get-group($coll)
        return
          (: we need to lower-case the ID string - groups are always lower-case :)
          if (contains( $groups, lower-case($r/id/text()) ) ) then
            <class id="{$r/id/text()}" coll="{$coll}" />
            (: when the group is different from the Coll. ID, use the group of the collection :)
          else if (contains( $groups, $collgroup ) ) then
            <class id="{$r/id/text()}" coll="{$coll}" />
          else if (contains( $groups, $r/id/text() ) ) then (: case: the user is 'all' or 'public' ->
                                                               $groups = list of id strings :)
            <class id="{$r/id/text()}" coll="{$coll}" />
          else ()
      }
      </classes>
};
