<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
  version="1.0">

  <xsl:param name="locale"/> <!-- Request parameter for changing locale -->
  <xsl:param name="term"/>   <!-- Request parameter for an incoming query - the query string -->
  <xsl:param name="field"/>  <!-- Request parameter for an incoming query - the field(s) to search -->

  <xsl:template match="document">
    <html>
      <head>
        <title><i18n:text>SearchFrameTitle</i18n:text></title>
      </head>
      <xsl:apply-templates />
    </html>
  </xsl:template>

  <xsl:template match="frame[@name='hovudmeny']">
    <frame noresize="{@noresize}"
           scrolling="{@scrolling}"
           name="{@name}"
           frameborder="{@frameborder}">
      <!-- Expand the src attribute with $locale if found -->
      <xsl:choose>
        <xsl:when test="$locale != ''">
          <xsl:attribute name="src">
            <xsl:value-of select="concat(@src,'?locale=',$locale)" />
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="src">
            <xsl:value-of select="@src" />
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
    </frame>
  </xsl:template>

  <xsl:template match="frame[@name='searchmenu']">
    <frame noresize="{@noresize}"
           name="{@name}"
           frameborder="{@frameborder}">

      <!-- Add the src attribute with $locale and $term if found -->
      <xsl:choose>
        <xsl:when test="$locale != ''">

          <xsl:choose>
            <xsl:when test="$term != ''">
              <xsl:attribute name="src">
                <xsl:value-of select="concat(@src,'?term=',$term,
                                            '&amp;locale=',$locale)" />
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="src">
                <xsl:value-of select="concat(@src,'?locale=',$locale)" />
              </xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>

        </xsl:when>
        <xsl:otherwise>

          <xsl:choose>
            <xsl:when test="$term != ''">
              <xsl:attribute name="src">
                <xsl:value-of select="concat(@src,'?term=',$term)" />
              </xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
              <xsl:attribute name="src">
                <xsl:value-of select="@src" />
              </xsl:attribute>
            </xsl:otherwise>
          </xsl:choose>

        </xsl:otherwise>
      </xsl:choose>

      <!-- START DEBUG: -->
              <xsl:attribute name="test">
                <xsl:value-of select="@src" />
              </xsl:attribute>
      <!-- END DEBUG -->

    </frame>
  </xsl:template>

  <xsl:template match="frame[@name='hitlist']">
    <frame name="{@name}"
           frameborder="{@frameborder}" >

      <!-- Add the src attribute if $term is found -->
        <xsl:choose>
          <xsl:when test="$term != ''">
<!--        <xsl:choose>
          <xsl:when test="$locale != ''">
            <xsl:attribute name="src">
              <xsl:value-of select="concat('termsearch.xq?term=',$term,
                                           '&amp;field=',$field,
                                           '&amp;locale=',$locale)" />
            </xsl:attribute>-->
            <xsl:attribute name="src">
              <xsl:value-of select="concat('query/search-entries.xq?term=',
                                            $term,
                                           '&amp;field=',
                                            $field,
                                           '&amp;mode=trad')" />
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise> 
            <xsl:attribute name="src">
              <xsl:value-of select="@src" />
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>

    </frame>
  </xsl:template>

  <xsl:template match="noframes">
    <noframes>
    	<i18n:text>NotWithoutFramesYet</i18n:text>
    </noframes>
  </xsl:template>

 <xsl:template match="@*|node()" priority="-1">
	<xsl:copy><xsl:apply-templates select="@*|node()"/></xsl:copy>
 </xsl:template>

</xsl:stylesheet>
