<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:exist="http://exist.sourceforge.net/NS/exist"
  xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
  version="1.0">

  <!-- Request parameter for an incoming query - the query string -->
  <xsl:param name="term"/>

  <xsl:template match="document">
    <xsl:variable name="css">
        <xsl:choose>
            <xsl:when test="header/style/@href">
                <xsl:value-of select="header/style/@href"/>
            </xsl:when>
            <xsl:otherwise>../risten.css</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <html>
      <head>
        <title><xsl:value-of select="header/title"/></title>
        <link rel="stylesheet" type="text/css" href="{$css}"/>
		<xsl:if test="header/style">
        	<xsl:copy-of select="header/style"/>
        </xsl:if>
        <xsl:if test="header/script">
            <xsl:copy-of select="header/script"/>
        </xsl:if>
      </head>

      <body>
        <xsl:attribute name="onLoad">
          <xsl:value-of select="body/@onLoad"/>
        </xsl:attribute>
        <xsl:apply-templates select="body"/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="header">
    <span class="header"><xsl:value-of select="./title/text()"/></span>
  </xsl:template>

  <xsl:template match="body">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="input[@name='term']">
    <input type="{@type}"
           name="{@name}"
           id="{@id}"
           size="{@size}" >
      <xsl:if test="$term != ''">
        <xsl:attribute name="value">
          <xsl:value-of select="$term" />
        </xsl:attribute>
      </xsl:if>
    </input>
  </xsl:template>

  <xsl:template match="termcolls">
    <select name="srchcoll" size="1" >
      <xsl:if test="@count > 1" >
        <option value="all" >
          <i18n:text>AllDicts</i18n:text>
        </option>
      </xsl:if>
      <xsl:apply-templates/>
    </select>
  </xsl:template>

  <xsl:template match="termcoll">
    <!-- Changed the option value from @coll to @id - it is easy to go from
         id to coll, but very cumbersome to go the other way. -->
    <!-- Changed it back, as it is actually very easy to go from the coll.
         path to the ID: just ask for the id ELEMENT in that collection. -->
    <option value="{@coll}" >
      <i18n:text catalogue="coll-short">
        <xsl:value-of select="@id"/>
      </i18n:text>
    </option>
  </xsl:template>

  <xsl:template match="dictcoll">
    <option value="{@coll}" >
      <i18n:text catalogue="coll-short">
        <xsl:value-of select="@id"/>
      </i18n:text>
    </option>
  </xsl:template>

  <xsl:template match="class">
    <option value="{@coll}" >
      <i18n:text catalogue="coll-short">
        <xsl:value-of select="@id"/>
      </i18n:text>
    </option>
  </xsl:template>

  <xsl:template match="termlangs">
  <!-- The attribute  multiple="false" is removed, to ensure that all browsers
       will disallow multiple selections - the processing of multiple selections
       isn't ready yet. -->
    <select name="showlang" size="{count(./language)+1}" multiple="true">
      <option value="all" selected="true"><i18n:text>AllLangs</i18n:text></option>
      <xsl:apply-templates/>
    </select>
  </xsl:template>

  <xsl:template match="language">
    <option value="{@id}" >
      <i18n:text>
        <xsl:value-of select="@id"/>
      </i18n:text>
    </option>
  </xsl:template>

  <xsl:template match="classification">
    <select size="1" name="class">
      <option value="all" >
        <i18n:text>AllClass</i18n:text>
      </option>
      <xsl:apply-templates/>
    </select>
  </xsl:template>

  <xsl:template match="macro">
    <option value="{@id}" title="{@id}">
      <xsl:value-of select="concat(@id,' — ')" />
      <i18n:text catalogue="SD-class"><xsl:value-of select="./@id"/></i18n:text>
    </option>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="micro">
    <option value="{@id}" title="{@id}">
      <xsl:text>&#160;&#160;&#160;</xsl:text>
      <i18n:text catalogue="SD-class"><xsl:value-of select="./@id"/></i18n:text>
    </option>
    <xsl:if test="./nano">
        <xsl:apply-templates>
          <xsl:with-param name="micro" select="@id" />
        </xsl:apply-templates>
    </xsl:if>
  </xsl:template>

  <xsl:template match="nano">
	<xsl:param name="micro"/>
    <option title="{@id}" >
      <xsl:attribute name="value">
        <xsl:value-of select="concat($micro,'-',@id)" />
      </xsl:attribute>
      <xsl:text>&#160;&#160;&#160;&#160;&#160;&#160;</xsl:text>
      <i18n:text catalogue="SD-class"><xsl:value-of select="./@id"/></i18n:text>
    </option>
  </xsl:template>

<!-- All the conditional processing in the two templates below is to allow
     proper treatment of Cocoon's i18n markup. The basic functionality is
     still to just copy the @title into a h1/h2 element. -->
<xsl:template match="body/section">
  <xsl:if test="@id">
    <a name="{@id}"></a>
  </xsl:if>
    <h1>
      <xsl:choose>
        <xsl:when test="@i18n:attr">
          <xsl:choose>
            <xsl:when test="contains(@title,':')">
              <i18n:text>
                <xsl:attribute name="i18n:catalogue">
                  <xsl:value-of select="substring-before(@title,':')"/>
                </xsl:attribute>
                <xsl:value-of select="substring-after(@title,':')"/>
              </i18n:text>
            </xsl:when>
            <xsl:otherwise>
              <i18n:text><xsl:value-of select="@title"/></i18n:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="@title"/>
        </xsl:otherwise>
      </xsl:choose>
    </h1>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="section/section">
	<p></p>
  <xsl:if test="@id">
    <a name="{@id}"></a>
  </xsl:if>
  <h2>
    <xsl:choose>
      <xsl:when test="@i18n:attr">
        <xsl:choose>
          <xsl:when test="contains(@title,':')">
            <i18n:text>
              <xsl:attribute name="i18n:catalogue">
                <xsl:value-of select="substring-before(@title,':')"/>
              </xsl:attribute>
              <xsl:value-of select="substring-after(@title,':')"/>
            </i18n:text>
          </xsl:when>
          <xsl:otherwise>
            <i18n:text><xsl:value-of select="@title"/></i18n:text>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="@title"/>
      </xsl:otherwise>
    </xsl:choose>
  </h2>
  <xsl:apply-templates/>
</xsl:template>

 <xsl:template match="@*|node()" priority="-1">
	<xsl:copy><xsl:apply-templates select="@*|node()"/></xsl:copy>
 </xsl:template>

</xsl:stylesheet>
